@@ -23,9 +23,6 @@
 #ifndef __E_CONTACT_EDITOR_H__
 #define __E_CONTACT_EDITOR_H__
 
-#include <bonobo/bonobo-ui-component.h>
-#include <glade/glade.h>
-
 #include "addressbook/gui/contact-editor/eab-editor.h"
 
 #include <libebook/e-book.h>
@@ -50,7 +47,6 @@ G_BEGIN_DECLS
 #define E_IS_CONTACT_EDITOR(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), E_TYPE_CONTACT_EDITOR))
 #define E_IS_CONTACT_EDITOR_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((obj), E_TYPE_CONTACT_EDITOR))
 
-
 typedef struct _EContactEditor       EContactEditor;
 typedef struct _EContactEditorClass  EContactEditorClass;
 
@@ -63,10 +59,7 @@ struct _EContactEditor
 	EBook *target_book;
 	EContact *contact;
 
-	/* UI handler */
-	BonoboUIComponent *uic;
-
-	GladeXML *gui;
+	GtkBuilder *builder;
 	GtkWidget *app;
 
 	GtkWidget *file_selector;
@@ -91,6 +84,9 @@ struct _EContactEditor
 	/* Whether an image is changed */
 	guint image_changed : 1;
 
+	/* Whether to try to reduce space used */
+	guint compress_ui : 1;
+
 	EList *writable_fields;
 
 	EList *required_fields;
@@ -111,11 +107,12 @@ struct _EContactEditorClass
 	EABEditorClass parent_class;
 };
 
-EContactEditor *e_contact_editor_new                (EBook          *book,
-						     EContact       *contact,
-						     gboolean        is_new_contact,
-						     gboolean        editable);
-GType           e_contact_editor_get_type           (void);
+GType		e_contact_editor_get_type	(void);
+EABEditor	*e_contact_editor_new		(EShell *shell,
+						 EBook *book,
+						 EContact *contact,
+						 gboolean is_new_contact,
+						 gboolean editable);
 
 G_END_DECLS
 
