@@ -232,6 +232,7 @@ dialog_destroyed_cb (GtkWidget *dialog, gpointer user_data)
 AlarmNotificationsDialog *
 notified_alarms_dialog_new (void)
 {
+	GtkWidget *container;
 	GtkWidget *edit_btn;
 	GtkWidget *snooze_btn;
 	GtkWidget *image;
@@ -272,7 +273,7 @@ notified_alarms_dialog_new (void)
 
 	if (!(an->dialog && an->scrolledwindow && an->treeview && an->snooze_time_min && an->snooze_time_hrs
 	      && an->description && an->location && edit_btn && snooze_btn && an->dismiss_btn)) {
-		g_message ("alarm_notify_dialog(): Could not find all widgets in Glade file!");
+		g_warning ("alarm_notify_dialog(): Could not find all widgets in alarm-notify.ui file!");
 		g_object_unref (an->builder);
 		g_free (an);
 		return NULL;
@@ -298,8 +299,13 @@ notified_alarms_dialog_new (void)
 		G_CALLBACK (tree_selection_changed_cb), an);
 
 	gtk_widget_realize (an->dialog);
-	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (an->dialog)->vbox), 0);
-	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (an->dialog)->action_area), 12);
+
+	container = gtk_dialog_get_action_area (GTK_DIALOG (an->dialog));
+	gtk_container_set_border_width (GTK_CONTAINER (container), 12);
+
+	container = gtk_dialog_get_content_area (GTK_DIALOG (an->dialog));
+	gtk_container_set_border_width (GTK_CONTAINER (container), 0);
+
 	image = e_builder_get_widget (an->builder, "alarm-image");
 	gtk_image_set_from_icon_name (
 		GTK_IMAGE (image), "stock_alarm", GTK_ICON_SIZE_DIALOG);
@@ -310,8 +316,8 @@ notified_alarms_dialog_new (void)
 	g_signal_connect (G_OBJECT (an->dialog), "response", G_CALLBACK (dialog_response_cb), an);
 	g_signal_connect (G_OBJECT (an->dialog), "destroy", G_CALLBACK (dialog_destroyed_cb), an);
 
-	if (!GTK_WIDGET_REALIZED (an->dialog))
-	gtk_widget_realize (an->dialog);
+	if (!gtk_widget_get_realized (an->dialog))
+		gtk_widget_realize (an->dialog);
 
 	gtk_window_set_icon_name (GTK_WINDOW (an->dialog), "stock_alarm");
 
