@@ -36,6 +36,7 @@
 #include <e-util/e-binding.h>
 #include <e-util/e-plugin-ui.h>
 #include <e-util/e-util-private.h>
+#include <e-util/e-ui-manager.h>
 
 #include "event-page.h"
 #include "recurrence-page.h"
@@ -89,16 +90,27 @@ static const gchar *ui =
 "    </menu>"
 "  </menubar>"
 "  <toolbar name='main-toolbar'>"
-"    <toolitem action='alarms'/>"
-"    <toolitem action='show-time-busy'/>"
-"    <toolitem action='recurrence'/>"
-"    <toolitem action='all-day-event'/>"
-"    <toolitem action='free-busy'/>"
+"    <placeholder name='content'>\n"
+"#if !EXPRESS\n"
+"      <toolitem action='alarms'/>\n"
+"#endif\n"
+"      <toolitem action='show-time-busy'/>\n"
+"#if !EXPRESS\n"
+"      <toolitem action='recurrence'/>\n"
+"#endif\n"
+"      <toolitem action='all-day-event'/>\n"
+"#if !EXPRESS\n"
+"      <toolitem action='free-busy'/>\n"
+"#endif\n"
+"    </placeholder>"
 "  </toolbar>"
 "</ui>";
 
-static void event_editor_edit_comp (CompEditor *editor, ECalComponent *comp);
-static gboolean event_editor_send_comp (CompEditor *editor, ECalComponentItipMethod method, gboolean strip_alarms);
+static void	event_editor_edit_comp		(CompEditor *editor,
+						 ECalComponent *comp);
+static gboolean	event_editor_send_comp		(CompEditor *editor,
+						 ECalComponentItipMethod method,
+						 gboolean strip_alarms);
 
 G_DEFINE_TYPE (EventEditor, event_editor, TYPE_COMP_EDITOR)
 
@@ -278,8 +290,11 @@ event_editor_constructor (GType type,
 	EventEditorPrivate *priv;
 	GtkActionGroup *action_group;
 	GtkWidget *content_area;
+	EShell *shell;
 	ECal *client;
 	gboolean is_meeting;
+	GtkWidget *alarm_page;
+	GtkWidget *attendee_page;
 
 	/* Chain up to parent's constructor() method. */
 	object = G_OBJECT_CLASS (event_editor_parent_class)->constructor (
@@ -288,6 +303,8 @@ event_editor_constructor (GType type,
 	editor = COMP_EDITOR (object);
 	priv = EVENT_EDITOR_GET_PRIVATE (object);
 
+	shell = comp_editor_get_shell (editor);
+
 	client = comp_editor_get_client (editor);
 	flags = comp_editor_get_flags (editor);
 	action_group = comp_editor_get_action_group (editor, "coordinated");
@@ -299,7 +316,7 @@ event_editor_constructor (GType type,
 	priv->event_page = event_page_new (priv->model, editor);
 	comp_editor_append_page (
 		editor, COMP_EDITOR_PAGE (priv->event_page),
-		_("Appoint_ment"), TRUE);
+		_("Appointment"), TRUE);
 
 	priv->recur_window = gtk_dialog_new_with_buttons (
 		_("Recurrence"), GTK_WINDOW (editor), GTK_DIALOG_MODAL,
@@ -316,11 +333,34 @@ event_editor_constructor (GType type,
 
 	priv->recur_page = recurrence_page_new (editor);
 	page = COMP_EDITOR_PAGE (priv->recur_page);
-	gtk_container_add (
-		GTK_CONTAINER (content_area),
-		comp_editor_page_get_widget (page));
-	gtk_widget_show_all (gtk_bin_get_child (GTK_BIN (priv->recur_window)));
-	comp_editor_append_page (editor, page, NULL, FALSE);
+	if (!e_shell_get_express_mode (shell)) {
+		gtk_container_add (
+			GTK_CONTAINER (content_area),
+			comp_editor_page_get_widget (page));
+		gtk_widget_show_all (gtk_bin_get_child (GTK_BIN (priv->recur_window)));
+		comp_editor_append_page (editor, page, NULL, FALSE);
+	} else {
+		comp_editor_append_page (editor, page, _("Recurrence"), TRUE);
+	}
+
+	if (e_shell_get_express_mode (shell)) {
+		ENameSelector *name_selector;
+
+		priv->sched_page = schedule_page_new (priv->model, editor);
+		page = COMP_EDITOR_PAGE (priv->sched_page);
+
+		name_selector = event_page_get_name_selector (priv->event_page);
+		schedule_page_set_name_selector (priv->sched_page, name_selector);
+
+		comp_editor_append_page (editor, page, _("Free/Busy"), TRUE);
+		schedule_page_update_free_busy (priv->sched_page);
+
+		/* Alarm page */
+		alarm_page = event_page_get_alarm_page (priv->event_page);
+		comp_editor_append_widget (editor, alarm_page, _("Alarm"), TRUE);
+		g_object_unref(alarm_page);
+
+	}
 
 	if (is_meeting) {
 
@@ -328,7 +368,9 @@ event_editor_constructor (GType type,
 			event_page_show_options (priv->event_page);
 
 		comp_editor_set_group_item (editor, TRUE);
-		if (!((flags & COMP_EDITOR_USER_ORG) || (flags & COMP_EDITOR_DELEGATE)|| (flags & COMP_EDITOR_NEW_ITEM))) {
+		if (!((flags & COMP_EDITOR_USER_ORG) ||
+			(flags & COMP_EDITOR_DELEGATE) ||
+			(flags & COMP_EDITOR_NEW_ITEM))) {
 			GtkAction *action;
 
 			action = comp_editor_get_action (editor, "free-busy");
@@ -337,6 +379,12 @@ event_editor_constructor (GType type,
 
 		event_page_set_meeting (priv->event_page, TRUE);
 		priv->meeting_shown=TRUE;
+
+		if (e_shell_get_express_mode (shell)) {
+			attendee_page = event_page_get_attendee_page (priv->event_page);
+			comp_editor_append_widget (editor, attendee_page, _("Attendees"), TRUE);
+			g_object_unref(attendee_page);
+		}
 	}
 
 	return object;
@@ -365,6 +413,8 @@ event_editor_dispose (GObject *object)
 	}
 
 	if (priv->model) {
+		g_signal_handlers_disconnect_by_func (
+			priv->model, event_editor_model_changed_cb, object);
 		g_object_unref (priv->model);
 		priv->model = NULL;
 	}
@@ -513,7 +563,7 @@ event_editor_init (EventEditor *ee)
 		G_N_ELEMENTS (meeting_entries), ee);
 
 	ui_manager = comp_editor_get_ui_manager (editor);
-	gtk_ui_manager_add_ui_from_string (ui_manager, ui, -1, &error);
+	e_ui_manager_add_ui_from_string (E_UI_MANAGER (ui_manager), ui, &error);
 
 	id = "org.gnome.evolution.event-editor";
 	e_plugin_ui_register_manager (ui_manager, id, ee);
@@ -524,6 +574,9 @@ event_editor_init (EventEditor *ee)
 		g_error_free (error);
 	}
 
+	action = comp_editor_get_action (editor, "print");
+	gtk_action_set_tooltip (action, _("Print this event"));
+
 	/* Hide send options. */
 	action = comp_editor_get_action (editor, "send-options");
 	gtk_action_set_visible (action, FALSE);
@@ -587,7 +640,8 @@ event_editor_edit_comp (CompEditor *editor, ECalComponent *comp)
 			gtk_action_set_visible (action, TRUE);
 		}
 
-		if (!(delegate && e_cal_get_static_capability (client, CAL_STATIC_CAPABILITY_DELEGATE_TO_MANY))) {
+		if (!(delegate && e_cal_get_static_capability (
+			client, CAL_STATIC_CAPABILITY_DELEGATE_TO_MANY))) {
 			event_page_remove_all_attendees (priv->event_page);
 
 			for (l = attendees; l != NULL; l = l->next) {
@@ -597,11 +651,15 @@ event_editor_edit_comp (CompEditor *editor, ECalComponent *comp)
 				if (delegate &&	!g_str_equal (itip_strip_mailto (ca->value), user_email))
 					continue;
 
-				ia = E_MEETING_ATTENDEE (e_meeting_attendee_new_from_e_cal_component_attendee (ca));
+				ia = E_MEETING_ATTENDEE (
+					e_meeting_attendee_new_from_e_cal_component_attendee (ca));
 
-				/* If we aren't the organizer or the attendee is just delegated, don't allow editing */
-				if (!comp_editor_get_user_org (editor) || e_meeting_attendee_is_set_delto (ia))
-					e_meeting_attendee_set_edit_level (ia,  E_MEETING_ATTENDEE_EDIT_NONE);
+				/* If we aren't the organizer or the attendee
+				 * is just delegated, don't allow editing. */
+				if (!comp_editor_get_user_org (editor) ||
+					e_meeting_attendee_is_set_delto (ia))
+					e_meeting_attendee_set_edit_level (
+						ia,  E_MEETING_ATTENDEE_EDIT_NONE);
 
 				event_page_add_attendee (priv->event_page, ia);
 
@@ -615,7 +673,9 @@ event_editor_edit_comp (CompEditor *editor, ECalComponent *comp)
 				EIterator *it;
 
 				accounts = itip_addresses_get ();
-				for (it = e_list_get_iterator((EList *)accounts);e_iterator_is_valid(it);e_iterator_next(it)) {
+				for (it = e_list_get_iterator((EList *)accounts);
+					e_iterator_is_valid(it);
+					e_iterator_next(it)) {
 					EMeetingAttendee *ia;
 
 					account = (EAccount*)e_iterator_get(it);
@@ -639,13 +699,17 @@ event_editor_edit_comp (CompEditor *editor, ECalComponent *comp)
 	}
 	e_cal_component_free_attendee_list (attendees);
 
-	comp_editor_set_needs_send (editor, priv->meeting_shown && (itip_organizer_is_user (comp, client) || itip_sentby_is_user (comp, client)));
+	comp_editor_set_needs_send (
+		editor, priv->meeting_shown && (itip_organizer_is_user (
+		comp, client) || itip_sentby_is_user (comp, client)));
 
 	priv->updating = FALSE;
 }
 
 static gboolean
-event_editor_send_comp (CompEditor *editor, ECalComponentItipMethod method, gboolean strip_alarms)
+event_editor_send_comp (CompEditor *editor,
+                        ECalComponentItipMethod method,
+                        gboolean strip_alarms)
 {
 	EventEditorPrivate *priv;
 	ECalComponent *comp = NULL;
@@ -673,7 +737,8 @@ event_editor_send_comp (CompEditor *editor, ECalComponentItipMethod method, gboo
 
  parent:
 	if (COMP_EDITOR_CLASS (event_editor_parent_class)->send_comp)
-		return COMP_EDITOR_CLASS (event_editor_parent_class)->send_comp (editor, method, strip_alarms);
+		return COMP_EDITOR_CLASS (event_editor_parent_class)->
+			send_comp (editor, method, strip_alarms);
 
 	return FALSE;
 }
