@@ -30,7 +30,6 @@
 #endif
 
 #include <string.h>
-#include <glade/glade.h>
 #include <glib/gi18n.h>
 
 #include "e-util/e-binding.h"
@@ -82,13 +81,18 @@ static const gchar *ui =
 "    </menu>"
 "  </menubar>"
 "  <toolbar name='main-toolbar'>"
-"    <toolitem action='view-time-zone'/>"
-"    <toolitem action='option-status'/>"
+"    <placeholder name='content'>"
+"      <toolitem action='view-time-zone'/>"
+"      <toolitem action='option-status'/>"
+"    </placeholder>"
 "  </toolbar>"
 "</ui>";
 
-static void task_editor_edit_comp (CompEditor *editor, ECalComponent *comp);
-static gboolean task_editor_send_comp (CompEditor *editor, ECalComponentItipMethod method, gboolean strip_alarms);
+static void	task_editor_edit_comp		(CompEditor *editor,
+						 ECalComponent *comp);
+static gboolean	task_editor_send_comp		(CompEditor *editor,
+						 ECalComponentItipMethod method,
+						 gboolean strip_alarms);
 
 G_DEFINE_TYPE (TaskEditor, task_editor, TYPE_COMP_EDITOR)
 
@@ -203,25 +207,12 @@ static void
 task_editor_constructed (GObject *object)
 {
 	TaskEditorPrivate *priv;
-	EShellSettings *shell_settings;
-	EShell *shell;
 
 	priv = TASK_EDITOR_GET_PRIVATE (object);
 
-	shell = comp_editor_get_shell (COMP_EDITOR (object));
-	shell_settings = e_shell_get_shell_settings (shell);
-
 	e_binding_new (
 		object, "client",
 		priv->model, "client");
-
-	e_binding_new (
-		shell_settings, "cal-free-busy-template",
-		priv->model, "free-busy-template");
-
-	e_binding_new (
-		shell_settings, "cal-timezone",
-		priv->model, "timezone");
 }
 
 static void
@@ -321,6 +312,8 @@ task_editor_init (TaskEditor *te)
 	CompEditor *editor = COMP_EDITOR (te);
 	GtkUIManager *ui_manager;
 	GtkActionGroup *action_group;
+	GtkWidget *content_area;
+	GtkAction *action;
 	const gchar *id;
 	GError *error = NULL;
 
@@ -332,7 +325,7 @@ task_editor_init (TaskEditor *te)
 	te->priv->task_page = task_page_new (te->priv->model, editor);
 	comp_editor_append_page (
 		editor, COMP_EDITOR_PAGE (te->priv->task_page),
-		_("_Task"), TRUE);
+		_("Task"), TRUE);
 
 	te->priv->task_details_window = gtk_dialog_new_with_buttons (
 		_("Task Details"), GTK_WINDOW (te), GTK_DIALOG_MODAL,
@@ -345,8 +338,10 @@ task_editor_init (TaskEditor *te)
 		G_CALLBACK(gtk_widget_hide), NULL);
 
 	te->priv->task_details_page = task_details_page_new (editor);
+	content_area = gtk_dialog_get_content_area (
+		GTK_DIALOG (te->priv->task_details_window));
 	gtk_container_add (
-		GTK_CONTAINER (GTK_DIALOG (te->priv->task_details_window)->vbox),
+		GTK_CONTAINER (content_area),
 		comp_editor_page_get_widget ((CompEditorPage *) te->priv->task_details_page));
 	gtk_widget_show_all (gtk_bin_get_child (GTK_BIN (te->priv->task_details_window)));
 	comp_editor_append_page (
@@ -374,6 +369,9 @@ task_editor_init (TaskEditor *te)
 		g_error_free (error);
 	}
 
+	action = comp_editor_get_action (editor, "print");
+	gtk_action_set_tooltip (action, _("Print this task"));
+
 	g_signal_connect_swapped (
 		te->priv->model, "row_changed",
 		G_CALLBACK (task_editor_model_changed_cb), te);
@@ -418,9 +416,12 @@ task_editor_edit_comp (CompEditor *editor, ECalComponent *comp)
 			EMeetingAttendee *ia;
 
 			ia = E_MEETING_ATTENDEE (e_meeting_attendee_new_from_e_cal_component_attendee (ca));
-			/* If we aren't the organizer or the attendee is just delegating, don't allow editing */
-			if (!comp_editor_get_user_org (editor) || e_meeting_attendee_is_set_delto (ia))
-				e_meeting_attendee_set_edit_level (ia,  E_MEETING_ATTENDEE_EDIT_NONE);
+			/* If we aren't the organizer or the attendee is just
+			 * delegating, don't allow editing. */
+			if (!comp_editor_get_user_org (editor) ||
+				e_meeting_attendee_is_set_delto (ia))
+				e_meeting_attendee_set_edit_level (
+					ia,  E_MEETING_ATTENDEE_EDIT_NONE);
 			task_page_add_attendee (priv->task_page, ia);
 
 			g_object_unref (ia);
@@ -433,7 +434,9 @@ task_editor_edit_comp (CompEditor *editor, ECalComponent *comp)
 			EIterator *it;
 
 			accounts = itip_addresses_get ();
-			for (it = e_list_get_iterator((EList *)accounts);e_iterator_is_valid(it);e_iterator_next(it)) {
+			for (it = e_list_get_iterator((EList *)accounts);
+				e_iterator_is_valid(it);
+				e_iterator_next(it)) {
 				EMeetingAttendee *ia;
 
 				account = (EAccount*)e_iterator_get(it);
@@ -456,13 +459,17 @@ task_editor_edit_comp (CompEditor *editor, ECalComponent *comp)
 	}
 	e_cal_component_free_attendee_list (attendees);
 
-	comp_editor_set_needs_send (editor, priv->assignment_shown && itip_organizer_is_user (comp, client));
+	comp_editor_set_needs_send (
+		editor, priv->assignment_shown &&
+		itip_organizer_is_user (comp, client));
 
 	priv->updating = FALSE;
 }
 
 static gboolean
-task_editor_send_comp (CompEditor *editor, ECalComponentItipMethod method, gboolean strip_alarms)
+task_editor_send_comp (CompEditor *editor,
+                       ECalComponentItipMethod method,
+                       gboolean strip_alarms)
 {
 	TaskEditorPrivate *priv;
 	ECalComponent *comp = NULL;
@@ -490,7 +497,8 @@ task_editor_send_comp (CompEditor *editor, ECalComponentItipMethod method, gbool
 
  parent:
 	if (COMP_EDITOR_CLASS (task_editor_parent_class)->send_comp)
-		return COMP_EDITOR_CLASS (task_editor_parent_class)->send_comp (editor, method, strip_alarms);
+		return COMP_EDITOR_CLASS (task_editor_parent_class)->
+			send_comp (editor, method, strip_alarms);
 
 	return FALSE;
 }
