@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -45,9 +45,9 @@
  * Return value: TRUE if the string is empty, FALSE otherwise.
  **/
 gboolean
-string_is_empty (const char *value)
+string_is_empty (const gchar *value)
 {
-	const char *p;
+	const gchar *p;
 	gboolean empty;
 
 	empty = TRUE;
@@ -55,7 +55,7 @@ string_is_empty (const char *value)
 	if (value) {
 		p = value;
 		while (*p) {
-			if (!isspace ((unsigned char) *p)) {
+			if (!isspace ((guchar) *p)) {
 				empty = FALSE;
 				break;
 			}
@@ -69,11 +69,11 @@ string_is_empty (const char *value)
 /**
  * get_uri_without_password
  */
-char *
-get_uri_without_password (const char *full_uri)
+gchar *
+get_uri_without_password (const gchar *full_uri)
 {
 	EUri *uri;
-	char *uristr;
+	gchar *uristr;
 
 	uri = e_uri_new (full_uri);
 	if (!uri)
@@ -98,15 +98,15 @@ get_position_in_array (GPtrArray *objects, gpointer item)
 	return -1;
 }
 
-char *
+gchar *
 calculate_time (time_t start, time_t end)
 {
 	time_t difference = end - start;
-	char *str;
-	int   hours, minutes;
-	char *times[4];
-	char *joined;
-	int   i;
+	gchar *str;
+	gint   hours, minutes;
+	gchar *times[4];
+	gchar *joined;
+	gint   i;
 
         i = 0;
 	if (difference >= 3600) {
@@ -123,7 +123,7 @@ calculate_time (time_t start, time_t end)
 	}
 	if (i == 0 || difference != 0) {
 		/* TRANSLATORS: here, "second" is the time division (like "minute"), not the ordinal number (like "third") */
-		times[i++] = g_strdup_printf (ngettext("%d second", "%d seconds", difference), (int)difference);
+		times[i++] = g_strdup_printf (ngettext("%d second", "%d seconds", difference), (gint)difference);
 	}
 
 	times[i] = NULL;
