@@ -41,6 +41,8 @@
 
 #define d(x)
 
+typedef GtkWidget * (*EConfigItemSectionFactoryFunc)(EConfig *ec, EConfigItem *, GtkWidget *parent, GtkWidget *old, gpointer data, GtkWidget **real_frame);
+
 struct _EConfigFactory {
 	gchar *id;
 	EConfigFactoryFunc func;
@@ -62,6 +64,7 @@ struct _widget_node {
 	EConfigItem *item;
 	GtkWidget *widget; /* widget created by the factory, if any */
 	GtkWidget *frame; /* if created by us */
+	GtkWidget *real_frame; /* used for sections and section tables, this is the real GtkFrame (whereas "frame" above is the internal vbox/table) */
 
 	guint empty:1;		/* set if empty (i.e. hidden) */
 };
@@ -87,6 +90,8 @@ struct _EConfigPrivate {
 
 static gpointer parent_class;
 
+static GtkWidget *ech_config_section_factory (EConfig *config, EConfigItem *item, GtkWidget *parent, GtkWidget *old, gpointer data, GtkWidget **real_frame);
+
 static void
 config_finalize (GObject *object)
 {
@@ -94,7 +99,7 @@ config_finalize (GObject *object)
 	EConfigPrivate *p = emp->priv;
 	GList *link;
 
-	d(printf("finalising EConfig %p\n", o));
+	d(printf("finalising EConfig %p\n", object));
 
 	g_free(emp->id);
 
@@ -381,54 +386,65 @@ ep_cmp(gconstpointer ap, gconstpointer bp)
 	return strcmp(a->item->path, b->item->path);
 }
 
-static struct _widget_node *
+static GList *
 ec_assistant_find_page (EConfig *ec, GtkWidget *page, gint *page_index)
 {
-	struct _widget_node *wn = NULL;
+	struct _widget_node *node = NULL;
 	GList *link;
 
 	g_return_val_if_fail (ec != NULL, NULL);
 	g_return_val_if_fail (GTK_IS_ASSISTANT (ec->widget), NULL);
 	g_return_val_if_fail (page != NULL, NULL);
 
-	link = ec->priv->widgets;
+	/* Assume failure, then if we do fail we can just return. */
+	if (page_index != NULL)
+		*page_index = -1;
 
-	while (link != NULL) {
-		wn = link->data;
+	/* Find the page widget in our sorted widget node list. */
+	for (link = ec->priv->widgets; link != NULL; link = link->next) {
+		node = link->data;
 
-		if (wn->frame == page
-		    && (wn->item->type == E_CONFIG_PAGE
-			|| wn->item->type == E_CONFIG_PAGE_START
-			|| wn->item->type == E_CONFIG_PAGE_FINISH))
-				break;
+		if (node->frame != page)
+			continue;
 
-		link = g_list_next (link);
+		if (node->item->type == E_CONFIG_PAGE)
+			break;
+
+		if (node->item->type == E_CONFIG_PAGE_START)
+			break;
+
+		if (node->item->type == E_CONFIG_PAGE_FINISH)
+			break;
+
+		if (node->item->type == E_CONFIG_PAGE_PROGRESS)
+			break;
 	}
 
-	g_return_val_if_fail (wn != NULL, NULL);
-
-	if (wn->frame != page)
-		wn = NULL;
+	/* FAIL: The widget is not in our list. */
+	if (link == NULL)
+		return NULL;
 
+	/* Find the corresponding GtkAssistant page index. */
 	if (page_index) {
-		if (wn) {
-			GtkAssistant *assistant = GTK_ASSISTANT (ec->widget);
-			gint index, count = gtk_assistant_get_n_pages (assistant);
+		GtkAssistant *assistant;
+		GtkWidget *nth_page;
+		gint ii, n_pages;
 
-			for (index = 0; index < count; index++) {
-				if (gtk_assistant_get_nth_page (assistant, index) == page)
-					break;
+		assistant = GTK_ASSISTANT (ec->widget);
+		n_pages = gtk_assistant_get_n_pages (assistant);
+
+		for (ii = 0; ii < n_pages; ii++) {
+			nth_page = gtk_assistant_get_nth_page (assistant, ii);
+			if (page == nth_page) {
+				*page_index = ii;
+				break;
 			}
-
-			if (index == count)
-				index = -1;
-			*page_index = index;
-		} else {
-			*page_index = -1;
 		}
+
+		g_warn_if_fail (ii < n_pages);
 	}
 
-	return wn;
+	return link;
 }
 
 static void
@@ -438,6 +454,7 @@ ec_assistant_check_current (EConfig *ec)
 	struct _finish_page_node *fp;
 	GtkAssistant *assistant;
 	GtkWidget *page;
+	GList *link;
 	gint page_no;
 
 	g_return_if_fail (GTK_IS_ASSISTANT (ec->widget));
@@ -452,8 +469,9 @@ ec_assistant_check_current (EConfig *ec)
 	page = gtk_assistant_get_nth_page (assistant, page_no);
 	g_return_if_fail (page != NULL);
 
-	wn = ec_assistant_find_page (ec, page, NULL);
-	g_return_if_fail (wn != NULL);
+	link = ec_assistant_find_page (ec, page, NULL);
+	g_return_if_fail (link != NULL);
+	wn = link->data;
 
 	/* this should come first, as the check function can change the finish state of the page */
 	gtk_assistant_set_page_complete (assistant, page, e_config_page_check (ec, wn->item->path));
@@ -477,37 +495,54 @@ ec_assistant_check_current (EConfig *ec)
 static gint
 ec_assistant_forward (gint current_page, gpointer user_data)
 {
+	GtkAssistant *assistant;
 	EConfig *ec = user_data;
-	struct _widget_node *wn;
-	gint next_page = current_page + 1;
+	struct _widget_node *node;
+	GtkWidget *page_widget;
 	GList *link = NULL;
+	gint next_page;
 
-	d(printf("next page from '%d'\n", current_page));
+	/* As far as we're concerned, the GtkAssistant is just an unordered
+	 * collection of pages.  Our sorted list of widget nodes determines
+	 * the next page. */
 
-	wn = ec_assistant_find_page (ec, gtk_assistant_get_nth_page (GTK_ASSISTANT (ec->widget), current_page), NULL);
+	assistant = GTK_ASSISTANT (ec->widget);
+	page_widget = gtk_assistant_get_nth_page (assistant, current_page);
+	link = ec_assistant_find_page (ec, page_widget, NULL);
 
-	/* XXX This is a little kludgy.  We have to find
-	 *     the GList node for the page we just found. */
-	if (wn != NULL)
-		link = g_list_find (ec->priv->widgets, wn);
+	g_return_val_if_fail (link != NULL, -1);
+	node = (struct _widget_node *) link->data;
 
-	if (link && link->next) {
-		for (link = link->next; link->next; link = link->next) {
-			wn = link->data;
+	/* If we're already on a FINISH page then we're done. */
+	if (node->item->type == E_CONFIG_PAGE_FINISH)
+		return -1;
 
-			if (!wn->empty && wn->frame != NULL
-			    && (wn->item->type == E_CONFIG_PAGE
-				|| wn->item->type == E_CONFIG_PAGE_START
-				|| wn->item->type == E_CONFIG_PAGE_FINISH))
-				break;
-		}
+	/* Find the next E_CONFIG_PAGE* type node. */
+	for (link = link->next; link != NULL; link = link->next) {
+		node = (struct _widget_node *) link->data;
+
+		if (node->empty || node->frame == NULL)
+			continue;
+
+		if (node->item->type == E_CONFIG_PAGE)
+			break;
+
+		if (node->item->type == E_CONFIG_PAGE_START)
+			break;
+
+		if (node->item->type == E_CONFIG_PAGE_FINISH)
+			break;
+
+		if (node->item->type == E_CONFIG_PAGE_PROGRESS)
+			break;
 	}
 
-	if (link && link->next) {
-		wn = link->data;
-		ec_assistant_find_page (ec, wn->frame, &next_page);
-		d(printf(" is %s (%d)\n",wn->item->path, next_page));
-	}
+	/* Find the corresponding GtkAssistant page number. */
+	if (link != NULL) {
+		node = (struct _widget_node *) link->data;
+		ec_assistant_find_page (ec, node->frame, &next_page);
+	} else
+		next_page = -1;
 
 	return next_page;
 }
@@ -519,7 +554,8 @@ ec_rebuild (EConfig *emp)
 	struct _widget_node *sectionnode = NULL, *pagenode = NULL;
 	GtkWidget *book = NULL, *page = NULL, *section = NULL, *root = NULL, *assistant = NULL;
 	gint pageno = 0, sectionno = 0, itemno = 0;
-	struct _widget_node *last_active_page = NULL;
+	gint n_visible_widgets = 0;
+	GList *last_active_link = NULL;
 	gboolean is_assistant;
 	GList *link;
 
@@ -533,9 +569,20 @@ ec_rebuild (EConfig *emp)
 	/* because rebuild destroys pages, and destroying active page causes crashes */
 	is_assistant = emp->widget && GTK_IS_ASSISTANT (emp->widget);
 	if (is_assistant) {
+		GtkAssistant *assistant;
 		gint page_index = gtk_assistant_get_current_page (GTK_ASSISTANT (emp->widget));
-		if (page_index != -1)
-			last_active_page = ec_assistant_find_page (emp, gtk_assistant_get_nth_page (GTK_ASSISTANT (emp->widget), page_index), NULL);
+
+		assistant = GTK_ASSISTANT (emp->widget);
+		page_index = gtk_assistant_get_current_page (assistant);
+
+		if (page_index != -1) {
+			GtkWidget *nth_page;
+
+			nth_page = gtk_assistant_get_nth_page (
+				GTK_ASSISTANT (emp->widget), page_index);
+			last_active_link = ec_assistant_find_page (
+				emp, nth_page, NULL);
+		}
 		gtk_assistant_set_current_page (GTK_ASSISTANT (emp->widget), 0);
 	}
 
@@ -550,28 +597,41 @@ ec_rebuild (EConfig *emp)
 		if (item->label != NULL)
 			translated_label = gettext (item->label);
 
-		/* If the last section doesn't contain anything, hide it */
+		/* If the last section doesn't contain any visible widgets, hide it */
 		if (sectionnode != NULL
 		    && sectionnode->frame != NULL
-		    && (item->type == E_CONFIG_PAGE_START
+		    && (item->type == E_CONFIG_PAGE
+			|| item->type == E_CONFIG_PAGE_START
 			|| item->type == E_CONFIG_PAGE_FINISH
-			|| item->type == E_CONFIG_PAGE
+			|| item->type == E_CONFIG_PAGE_PROGRESS
 			|| item->type == E_CONFIG_SECTION
 			|| item->type == E_CONFIG_SECTION_TABLE)) {
-			if ((sectionnode->empty = itemno == 0)) {
-				gtk_widget_hide(sectionnode->frame);
+			if ((sectionnode->empty = (itemno == 0 || n_visible_widgets == 0))) {
+				if (sectionnode->real_frame)
+					gtk_widget_hide(sectionnode->real_frame);
+
+				if (sectionnode->frame)
+					gtk_widget_hide(sectionnode->frame);
+
 				sectionno--;
-			} else
-				gtk_widget_show(sectionnode->frame);
+			} else {
+				if (sectionnode->real_frame)
+					gtk_widget_show(sectionnode->real_frame);
+
+				if (sectionnode->frame)
+					gtk_widget_show(sectionnode->frame);
+			}
+
 			d(printf("%s section '%s' [sections=%d]\n", sectionnode->empty?"hiding":"showing", sectionnode->item->path, sectionno));
 		}
 
 		/* If the last page doesn't contain anything, hide it */
 		if (pagenode != NULL
 		    && pagenode->frame != NULL
-		    && (item->type == E_CONFIG_PAGE_START
+		    && (item->type == E_CONFIG_PAGE
+			|| item->type == E_CONFIG_PAGE_START
 			|| item->type == E_CONFIG_PAGE_FINISH
-			|| item->type == E_CONFIG_PAGE)) {
+			|| item->type == E_CONFIG_PAGE_PROGRESS)) {
 			if ((pagenode->empty = sectionno == 0)) {
 				gtk_widget_hide(pagenode->frame);
 				pageno--;
@@ -659,8 +719,7 @@ ec_rebuild (EConfig *emp)
 				break;
 			}
 
-			if (item->type == E_CONFIG_PAGE_FINISH || wn->widget == NULL) {
-				/* always rebuild finish page, to have it as the last page */
+			if (wn->widget == NULL) {
 				if (item->factory) {
 					page = item->factory(emp, item, root, wn->frame, wn->context->data);
 				} else {
@@ -710,7 +769,8 @@ ec_rebuild (EConfig *emp)
 			sectionnode = NULL;
 			sectionno = 1; /* never want to hide these */
 			break;
-		case E_CONFIG_PAGE: {
+		case E_CONFIG_PAGE:
+		case E_CONFIG_PAGE_PROGRESS:
 			/* CONFIG_PAGEs depend on the config type.
 			   E_CONFIG_BOOK:
 				The page is a VBox, stored in the notebook.
@@ -722,6 +782,11 @@ ec_rebuild (EConfig *emp)
 				g_warning("EConfig page defined before container widget: %s", item->path);
 				break;
 			}
+			if (item->type == E_CONFIG_PAGE_PROGRESS &&
+			    emp->type != E_CONFIG_ASSISTANT) {
+				g_warning("EConfig assistant progress pages can't be used on E_CONFIG_BOOKs");
+				break;
+			}
 
 			if (item->factory) {
 				page = item->factory(emp, item, root, wn->frame, wn->context->data);
@@ -746,7 +811,7 @@ ec_rebuild (EConfig *emp)
 					} else {
 						gtk_assistant_prepend_page (GTK_ASSISTANT (assistant), page);
 					}
-					gtk_assistant_set_page_type (GTK_ASSISTANT (assistant), page, GTK_ASSISTANT_PAGE_CONTENT);
+					gtk_assistant_set_page_type (GTK_ASSISTANT (assistant), page, item->type == E_CONFIG_PAGE ? GTK_ASSISTANT_PAGE_CONTENT : GTK_ASSISTANT_PAGE_PROGRESS);
 					gtk_assistant_set_page_title (GTK_ASSISTANT (assistant), page, translated_label);
 					gtk_widget_show_all (page);
 
@@ -777,7 +842,7 @@ ec_rebuild (EConfig *emp)
 			wn->widget = page;
 			if (page)
 				g_signal_connect(page, "destroy", G_CALLBACK(gtk_widget_destroyed), &wn->widget);
-			break; }
+			break;
 		case E_CONFIG_SECTION:
 		case E_CONFIG_SECTION_TABLE:
 			/* The section factory is always called with
@@ -791,12 +856,35 @@ ec_rebuild (EConfig *emp)
 			}
 
 			itemno = 0;
+			n_visible_widgets = 0;
+
+			d(printf("Building section %s - '%s' - %s factory\n", item->path, item->label, item->factory ? "with" : "without"));
+
 			if (item->factory) {
-				section = item->factory(emp, item, page, wn->widget, wn->context->data);
+				/* For sections, we pass an extra argument to the usual EConfigItemFactoryFunc.
+				 * If this is an automatically-generated section, that extra argument (real_frame from
+				 * EConfigItemSectionFactoryFunc) will contain the actual GtkFrame upon returning.
+				 */
+				EConfigItemSectionFactoryFunc factory = (EConfigItemSectionFactoryFunc) item->factory;
+
+				section = factory(emp, item, page, wn->widget, wn->context->data, &wn->real_frame);
 				wn->frame = section;
 				if (section)
 					itemno = 1;
 
+				if (factory != ech_config_section_factory) {
+					/* This means there is a section that came from a user-specified factory,
+					 * so we don't know what is inside the section.  In that case, we increment
+					 * n_visible_widgets so that the section will not get hidden later (we don't know
+					 * if the section is empty or not, so we cannot decide to hide it).
+					 *
+					 * For automatically-generated sections, we use a special ech_config_section_factory() -
+					 * see emph_construct_item().
+					 */
+					n_visible_widgets++;
+					d(printf ("  n_visible_widgets++ because there is a section factory -> frame=%p\n", section));
+				}
+
 				if (section
 				    && ((item->type == E_CONFIG_SECTION && !GTK_IS_BOX(section))
 					|| (item->type == E_CONFIG_SECTION_TABLE && !GTK_IS_TABLE(section))))
@@ -878,6 +966,11 @@ ec_rebuild (EConfig *emp)
 
 			d(printf("item %d:%s widget %p\n", itemno, item->path, w));
 
+			d(printf ("  item %s: (%s - %s)\n",
+				  item->path,
+				  g_type_name_from_instance ((GTypeInstance *) w),
+				  gtk_widget_get_visible (w) ? "visible" : "invisible"));
+
 			if (wn->widget && wn->widget != w) {
 				d(printf("destroy old widget for item '%s'\n", item->path));
 				gtk_widget_destroy(wn->widget);
@@ -887,18 +980,32 @@ ec_rebuild (EConfig *emp)
 			if (w) {
 				g_signal_connect(w, "destroy", G_CALLBACK(gtk_widget_destroyed), &wn->widget);
 				itemno++;
+
+				if (gtk_widget_get_visible (w))
+					n_visible_widgets++;
 			}
 			break;
 		}
 	}
 
-	/* If the last section doesn't contain anything, hide it */
+	/* If the last section doesn't contain any visible widgets, hide it */
 	if (sectionnode != NULL && sectionnode->frame != NULL) {
-		if ((sectionnode->empty = itemno == 0)) {
-			gtk_widget_hide(sectionnode->frame);
+		d(printf ("Section %s - %d visible widgets (frame=%p)\n", sectionnode->item->path, n_visible_widgets, sectionnode->frame));
+		if ((sectionnode->empty = (itemno == 0 || n_visible_widgets == 0))) {
+			if (sectionnode->real_frame)
+				gtk_widget_hide(sectionnode->real_frame);
+
+			if (sectionnode->frame)
+				gtk_widget_hide(sectionnode->frame);
+
 			sectionno--;
-		} else
-			gtk_widget_show(sectionnode->frame);
+		} else {
+			if (sectionnode->real_frame)
+				gtk_widget_show(sectionnode->real_frame);
+
+			if (sectionnode->frame)
+				gtk_widget_show(sectionnode->frame);
+		}
 		d(printf("%s section '%s' [sections=%d]\n", sectionnode->empty?"hiding":"showing", sectionnode->item->path, sectionno));
 	}
 
@@ -920,11 +1027,15 @@ ec_rebuild (EConfig *emp)
 		}
 	}
 
-	if (is_assistant && last_active_page) {
+	if (is_assistant && last_active_link != NULL) {
+		GtkAssistant *assistant;
+		struct _widget_node *wn;
 		gint page_index = -1;
 
-		ec_assistant_find_page (emp, last_active_page->frame, &page_index);
-		gtk_assistant_set_current_page (GTK_ASSISTANT (emp->widget), page_index);
+		wn = last_active_link->data;
+		assistant = GTK_ASSISTANT (emp->widget);
+		ec_assistant_find_page (emp, wn->frame, &page_index);
+		gtk_assistant_set_current_page (assistant, page_index);
 	}
 }
 
@@ -1118,8 +1229,8 @@ ec_idle_handler_for_rebuild (gpointer data)
 
 /**
  * e_config_target_changed:
- * @emp:
- * @how:
+ * @emp: an #EConfig
+ * @how: an enum value indicating how the target has changed
  *
  * Indicate that the target has changed.  This may be called by the
  * self-aware target itself, or by the driving code.  If @how is
@@ -1129,7 +1240,8 @@ ec_idle_handler_for_rebuild (gpointer data)
  * This is used to sensitise Assistant next/back buttons and the Apply
  * button for the Notebook mode.
  **/
-void e_config_target_changed(EConfig *emp, e_config_target_change_t how)
+void
+e_config_target_changed(EConfig *emp, e_config_target_change_t how)
 {
 	if (how == E_CONFIG_TARGET_CHANGED_REBUILD) {
 		g_idle_add (ec_idle_handler_for_rebuild, emp);
@@ -1142,7 +1254,7 @@ void e_config_target_changed(EConfig *emp, e_config_target_change_t how)
 
 /**
  * e_config_abort:
- * @ec:
+ * @config: an #EConfig
  *
  * Signify that the stateful configuration changes must be discarded
  * to all listeners.  This is used by self-driven assistant or notebook, or
@@ -1171,7 +1283,7 @@ e_config_abort (EConfig *config)
 
 /**
  * e_config_commit:
- * @ec:
+ * @ec: an #EConfig
  *
  * Signify that the stateful configuration changes should be saved.
  * This is used by the self-driven assistant or notebook, or may be used
@@ -1254,7 +1366,8 @@ e_config_page_get(EConfig *ec, const gchar *pageid)
 		if (!wn->empty
 		    && (wn->item->type == E_CONFIG_PAGE
 			|| wn->item->type == E_CONFIG_PAGE_START
-			|| wn->item->type == E_CONFIG_PAGE_FINISH)
+			|| wn->item->type == E_CONFIG_PAGE_FINISH
+			|| wn->item->type == E_CONFIG_PAGE_PROGRESS)
 		    && !strcmp(wn->item->path, pageid))
 			return wn->frame;
 
@@ -1290,7 +1403,8 @@ e_config_page_next(EConfig *ec, const gchar *pageid)
 		if (!wn->empty
 		    && (wn->item->type == E_CONFIG_PAGE
 			|| wn->item->type == E_CONFIG_PAGE_START
-			|| wn->item->type == E_CONFIG_PAGE_FINISH)) {
+			|| wn->item->type == E_CONFIG_PAGE_FINISH
+			|| wn->item->type == E_CONFIG_PAGE_PROGRESS)) {
 			if (found)
 				return wn->item->path;
 			else if (strcmp(wn->item->path, pageid) == 0)
@@ -1305,7 +1419,7 @@ e_config_page_next(EConfig *ec, const gchar *pageid)
 
 /**
  * e_config_page_next:
- * @ec:
+ * @ec: an #EConfig
  * @pageid: The path of the page item.
  *
  * Find the path of the previous visible page before @pageid.  If @pageid
@@ -1329,7 +1443,8 @@ e_config_page_prev(EConfig *ec, const gchar *pageid)
 		if (!wn->empty
 		    && (wn->item->type == E_CONFIG_PAGE
 			|| wn->item->type == E_CONFIG_PAGE_START
-			|| wn->item->type == E_CONFIG_PAGE_FINISH)) {
+			|| wn->item->type == E_CONFIG_PAGE_FINISH
+			|| wn->item->type == E_CONFIG_PAGE_PROGRESS)) {
 			if (found)
 				return wn->item->path;
 			else if (strcmp(wn->item->path, pageid) == 0)
@@ -1584,7 +1699,8 @@ ech_config_section_factory (EConfig *config,
                             EConfigItem *item,
                             GtkWidget *parent,
                             GtkWidget *old,
-                            gpointer data)
+                            gpointer data,
+			    GtkWidget **real_frame)
 {
 	struct _EConfigHookGroup *group = data;
 	GtkWidget *label = NULL;
@@ -1611,6 +1727,8 @@ ech_config_section_factory (EConfig *config,
 	gtk_frame_set_shadow_type (GTK_FRAME (widget), GTK_SHADOW_NONE);
 	gtk_box_pack_start (GTK_BOX (parent), widget, FALSE, FALSE, 0);
 
+	*real_frame = widget;
+
 	/* This is why we have a custom factory for sections.
 	 * When the plugin is disabled the frame is invisible. */
 	plugin = group->hook->hook.plugin;
@@ -1666,9 +1784,9 @@ emph_construct_item(EPluginHook *eph, EConfigHookGroup *menu, xmlNodePtr root, E
 	if (item->user_data)
 		item->factory = ech_config_widget_factory;
 	else if (item->type == E_CONFIG_SECTION)
-		item->factory = ech_config_section_factory;
+		item->factory = (EConfigItemFactoryFunc) ech_config_section_factory;
 	else if (item->type == E_CONFIG_SECTION_TABLE)
-		item->factory = ech_config_section_factory;
+		item->factory = (EConfigItemFactoryFunc) ech_config_section_factory;
 
 	d(printf("   path=%s label=%s factory=%s\n", item->path, item->label, (gchar *)item->user_data));
 
