@@ -34,7 +34,7 @@
 #include <gtk/gtk.h>
 #include <libxml/xmlmemory.h>
 
-#include <camel/camel-iconv.h>
+#include <camel/camel.h>
 
 #include <glib/gi18n.h>
 #include "e-unicode.h"
@@ -84,7 +84,7 @@ e_utf8_from_iconv_string_sized (iconv_t ic, const gchar *string, gint bytes)
 		/* iso-8859-1 */
 		ib = (gchar *) string;
 		new = ob = (gchar *)g_new (unsigned char, bytes * 2 + 1);
-		for (i = 0; i < (bytes); i ++) {
+		for (i = 0; i < (bytes); i++) {
 			ob += e_unichar_to_utf8 (ib[i], ob);
 		}
 		*ob = '\0';
@@ -212,12 +212,14 @@ e_utf8_from_locale_string_sized (const gchar *string, gint bytes)
 
 /**
  * e_utf8_ensure_valid:
- * @string String to make valid UTF-8.
+ * @string: string to make valid UTF-8
  *
- * Ensures the returned string will be valid UTF-8 string, thus gtk functions expecting
- * only valid UTF-8 texts will not crash.
+ * Ensures the returned string will be valid UTF-8 string, thus GTK+
+ * functions expecting only valid UTF-8 text will not crash.
  *
- * Returned pointer should be freed with g_free.
+ * Returned pointer should be freed with g_free().
+ *
+ * Returns: a newly-allocated UTF-8 string
  **/
 gchar *
 e_utf8_ensure_valid (const gchar *string)
