@@ -58,26 +58,6 @@
 #include "e-util.h"
 #include "e-util-private.h"
 
-/**
- * e_get_user_data_dir:
- *
- * Returns the base directory for Evolution-specific user data.
- * The string is owned by Evolution and must not be modified or freed.
- *
- * Returns: base directory for user data
- **/
-const gchar *
-e_get_user_data_dir (void)
-{
-	static gchar *dirname = NULL;
-
-	if (G_UNLIKELY (dirname == NULL))
-		dirname = g_build_filename (
-			g_get_home_dir (), ".evolution", NULL);
-
-	return dirname;
-}
-
 /**
  * e_get_gnome2_user_dir:
  *
@@ -560,15 +540,15 @@ e_str_without_underscores (const gchar *string)
 	new_string = g_malloc (strlen (string) + 1);
 
 	dp = new_string;
-	for (sp = string; *sp != '\0'; sp ++) {
+	for (sp = string; *sp != '\0'; sp++) {
 		if (*sp != '_') {
 			*dp = *sp;
-			dp ++;
+			dp++;
 		} else if (sp[1] == '_') {
 			/* Translate "__" in "_".  */
 			*dp = '_';
-			dp ++;
-			sp ++;
+			dp++;
+			sp++;
 		}
 	}
 	*dp = 0;
@@ -707,7 +687,7 @@ e_format_number (gint number)
 		}
 		char_length += strlen(group);
 		list = g_list_prepend(list, group);
-		group_count ++;
+		group_count++;
 	}
 
 	if (list) {
@@ -1321,8 +1301,6 @@ get_font_options (void)
 
 /* Evolution Locks for crash recovery */
 
-#define LOCK_FILE ".running"
-
 static const gchar *
 get_lock_filename (void)
 {
@@ -1330,7 +1308,7 @@ get_lock_filename (void)
 
 	if (G_UNLIKELY (filename == NULL))
 		filename = g_build_filename (
-			e_get_user_data_dir (), LOCK_FILE, NULL);
+			e_get_user_config_dir (), ".running", NULL);
 
 	return filename;
 }
