@@ -26,11 +26,14 @@
 #include <sys/types.h>
 #include <gtk/gtk.h>
 #include <limits.h>
-#include <camel/camel.h>
 #include <gconf/gconf-client.h>
 
 #include <e-util/e-marshal.h>
 
+/* e_get_user_data_dir() used to live here, so #include its new home
+ * for backward-compatibility (not that we really care about that). */
+#include <libedataserver/e-data-server-util.h>
+
 /* Convenience macro to help migrate from libglade to GtkBuilder.
  * Use it as a direct replacement for glade_xml_get_widget(). */
 #define e_builder_get_widget(builder, name) \
@@ -47,7 +50,6 @@ typedef enum {
 
 typedef void (*ETypeFunc) (GType type, gpointer user_data);
 
-const gchar *	e_get_user_data_dir		(void);
 const gchar *	e_get_gnome2_user_dir		(void);
 const gchar *	e_get_accels_filename		(void);
 void		e_show_uri			(GtkWindow *parent,
@@ -142,11 +144,6 @@ GSList *	e_util_get_category_filter_options
 void		e_util_set_source_combo_box_list(GtkWidget *source_combo_box,
 						 const gchar *source_gconf_path);
 
-/* Camel uses its own object system, so we have to box
- * CamelObjects to safely use them as GObject properties. */
-#define E_TYPE_CAMEL_OBJECT (e_camel_object_get_type ())
-GType		e_camel_object_get_type		(void);
-
 G_END_DECLS
 
 #endif /* E_UTIL_H */
