@@ -32,6 +32,7 @@
 #include "e-util/e-binding.h"
 #include "e-util/e-charset.h"
 #include "e-util/e-util.h"
+#include "e-util/e-alert-dialog.h"
 #include "e-util/gconf-bridge.h"
 #include "shell/e-shell-utils.h"
 #include "widgets/misc/e-popup-action.h"
@@ -52,6 +53,12 @@
 #include "mail/mail-vfolder.h"
 #include "mail/message-list.h"
 
+#if HAVE_CLUTTER
+#include <clutter/clutter.h>
+#include <mx/mx.h>
+#include <clutter-gtk/clutter-gtk.h>
+#endif
+
 #define E_MAIL_READER_GET_PRIVATE(obj) \
 	((EMailReaderPrivate *) g_object_get_qdata \
 	(G_OBJECT (obj), quark_private))
@@ -122,7 +129,7 @@ action_mail_add_sender_cb (GtkAction *action,
 {
 	EShell *shell;
 	EShellBackend *shell_backend;
-	CamelMessageInfo *info;
+	CamelMessageInfo *info = NULL;
 	CamelFolder *folder;
 	GPtrArray *uids;
 	const gchar *address;
@@ -605,7 +612,7 @@ static void
 action_mail_message_open_cb (GtkAction *action,
                              EMailReader *reader)
 {
-	e_mail_reader_open_selected (reader);
+	e_mail_reader_open_selected_mail (reader);
 }
 
 static void
@@ -670,6 +677,9 @@ action_mail_next_cb (GtkAction *action,
 	GtkWidget *message_list;
 	MessageListSelectDirection direction;
 	guint32 flags, mask;
+#if HAVE_CLUTTER
+	ClutterActor *actor;
+#endif
 
 	direction = MESSAGE_LIST_SELECT_NEXT;
 	flags = 0;
@@ -677,6 +687,16 @@ action_mail_next_cb (GtkAction *action,
 
 	message_list = e_mail_reader_get_message_list (reader);
 
+#if HAVE_CLUTTER
+	actor = g_object_get_data (G_OBJECT (message_list), "preview-actor");
+	if (actor != NULL) {
+		clutter_actor_set_opacity (actor, 0);
+		clutter_actor_animate (
+			actor, CLUTTER_EASE_OUT_SINE,
+			500, "opacity", 255, NULL);
+	}
+#endif
+
 	message_list_select (
 		MESSAGE_LIST (message_list), direction, flags, mask);
 }
@@ -819,25 +839,265 @@ action_mail_redirect_cb (GtkAction *action,
 	em_utils_redirect_message_by_uid (folder, uid);
 }
 
+static void
+action_mail_reply_all_check (CamelFolder *folder,
+                             const gchar *uid,
+                             CamelMimeMessage *message,
+                             gpointer user_data)
+{
+	EMailReader *reader = user_data;
+	CamelInternetAddress *to, *cc;
+	gint recip_count = 0;
+	gint mode = REPLY_MODE_ALL;
+
+	if (!message)
+		return;
+
+	/* get_message_free () will unref the message, so we need to take an
+	   extra ref for e_mail_reader_reply_to_message () to own. */
+	g_object_ref (message);
+	to = camel_mime_message_get_recipients (message, CAMEL_RECIPIENT_TYPE_TO);
+	cc = camel_mime_message_get_recipients (message, CAMEL_RECIPIENT_TYPE_CC);
+
+	recip_count = camel_address_length (CAMEL_ADDRESS (to));
+	recip_count += camel_address_length (CAMEL_ADDRESS (cc));
+
+	if (recip_count >= 15) {
+		GConfClient *gconf = mail_config_get_gconf_client ();
+		GtkWidget *dialog;
+		GtkWidget *content_area, *check;
+		gint response;
+
+		dialog = e_alert_dialog_new_for_args (
+			e_mail_reader_get_window (reader),
+			"mail:ask-reply-many-recips", NULL);
+
+		/* Check buttons */
+		check = gtk_check_button_new_with_mnemonic (_("_Do not ask me again."));
+		gtk_container_set_border_width (GTK_CONTAINER (check), 12);
+		content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+		gtk_box_pack_start (GTK_BOX (content_area), check, TRUE, TRUE, 0);
+		gtk_widget_show (check);
+
+		response = gtk_dialog_run (GTK_DIALOG (dialog));
+
+		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check)))
+			gconf_client_set_bool (gconf, "/apps/evolution/mail/prompts/reply_many_recips", FALSE, NULL);
+
+		gtk_widget_destroy (dialog);
+
+		if (response == GTK_RESPONSE_NO)
+			mode = REPLY_MODE_SENDER;
+		else if (response == GTK_RESPONSE_CANCEL)
+			return;
+	}
+
+	e_mail_reader_reply_to_message (reader, message, mode);
+}
+
 static void
 action_mail_reply_all_cb (GtkAction *action,
                           EMailReader *reader)
 {
-	e_mail_reader_reply_to_message (reader, REPLY_MODE_ALL);
+	guint32 state = e_mail_reader_check_state (reader);
+	GConfClient *gconf = mail_config_get_gconf_client ();
+
+	if (gconf_client_get_bool (gconf, "/apps/evolution/mail/prompts/reply_many_recips", NULL) &&
+	    !(state & E_MAIL_READER_SELECTION_IS_MAILING_LIST)) {
+		CamelMimeMessage *message = NULL;
+		EWebView *web_view;
+		EMFormatHTML *formatter;
+
+		formatter = e_mail_reader_get_formatter (reader);
+		web_view = em_format_html_get_web_view (formatter);
+		if (gtk_widget_get_mapped (GTK_WIDGET (web_view)))
+			message = CAMEL_MIME_MESSAGE (EM_FORMAT (formatter)->message);
+
+		if (!message) {
+			CamelFolder *folder;
+			GtkWidget *message_list;
+			gchar *uid;
+
+			folder = e_mail_reader_get_folder (reader);
+			message_list = e_mail_reader_get_message_list (reader);
+
+			uid = MESSAGE_LIST (message_list)->cursor_uid;
+			g_return_if_fail (uid != NULL);
+
+			mail_get_message (folder, uid, action_mail_reply_all_check, reader, mail_msg_unordered_push);
+			return;
+		}
+		action_mail_reply_all_check (NULL, NULL, message, reader);
+		return;
+	}
+
+	e_mail_reader_reply_to_message (reader, NULL, REPLY_MODE_ALL);
+}
+
+static void
+action_mail_reply_group_cb (GtkAction *action,
+			    EMailReader *reader)
+{
+	GConfClient *gconf = mail_config_get_gconf_client ();
+	gboolean reply_list = gconf_client_get_bool (gconf,
+					"/apps/evolution/mail/composer/group_reply_to_list", NULL);
+	guint32 state = e_mail_reader_check_state (reader);
+
+	if (reply_list && (state & E_MAIL_READER_SELECTION_IS_MAILING_LIST))
+		e_mail_reader_reply_to_message (reader, NULL, REPLY_MODE_LIST);
+	else
+		action_mail_reply_all_cb (action, reader);
 }
 
 static void
 action_mail_reply_list_cb (GtkAction *action,
                            EMailReader *reader)
 {
-	e_mail_reader_reply_to_message (reader, REPLY_MODE_LIST);
+	e_mail_reader_reply_to_message (reader, NULL, REPLY_MODE_LIST);
+}
+
+static void
+action_mail_reply_sender_check (CamelFolder *folder, const gchar *uid, CamelMimeMessage *message, gpointer user_data)
+{
+	GConfClient *gconf = mail_config_get_gconf_client ();
+	EMailReader *reader = user_data;
+	gint mode = REPLY_MODE_SENDER;
+
+	if (!message)
+		return;
+
+	/* get_message_free () will unref the message, so we need to take an
+	   extra ref for e_mail_reader_reply_to_message () to own. */
+	g_object_ref (message);
+
+	/* Don't do the "Are you sure you want to reply in private?" pop-up if
+	   it's a Reply-To: munged list message... unless we're ignoring munging */
+	if (gconf_client_get_bool (gconf, "/apps/evolution/mail/composer/ignore_list_reply_to", NULL)
+	    || !em_utils_is_munged_list_message (message)) {
+		GtkWidget *dialog;
+		GtkWidget *content_area, *check;
+		gint response;
+
+		dialog = e_alert_dialog_new_for_args (
+			e_mail_reader_get_window (reader),
+			"mail:ask-list-private-reply", NULL);
+
+		/* Check buttons */
+		check = gtk_check_button_new_with_mnemonic (
+			_("_Do not ask me again."));
+		gtk_container_set_border_width ((GtkContainer *)check, 12);
+		content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+		gtk_box_pack_start (
+			GTK_BOX (content_area), check, TRUE, TRUE, 0);
+		gtk_widget_show (check);
+
+		response = gtk_dialog_run (GTK_DIALOG (dialog));
+
+		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check)))
+			gconf_client_set_bool (
+				gconf, "/apps/evolution/mail/prompts/private_list_reply", FALSE, NULL);
+
+		gtk_widget_destroy (dialog);
+
+		if (response == GTK_RESPONSE_YES)
+			mode = REPLY_MODE_ALL;
+		else if (response == GTK_RESPONSE_OK)
+			mode = REPLY_MODE_LIST;
+		else if (response == GTK_RESPONSE_CANCEL)
+			return;
+	} else if (gconf_client_get_bool (gconf, "/apps/evolution/mail/prompts/list_reply_to", NULL)) {
+		GtkWidget *dialog;
+		GtkWidget *content_area;
+		GtkWidget *vbox;
+		GtkWidget *check_again;
+		GtkWidget *check_always_ignore;
+		gint response;
+
+		dialog = e_alert_dialog_new_for_args (
+			e_mail_reader_get_window (reader),
+			"mail:ask-list-honour-reply-to", NULL);
+
+		/*Check buttons*/
+		vbox = gtk_vbox_new (FALSE, 0);
+		content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+		gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
+		gtk_box_pack_start (GTK_BOX (content_area), vbox, TRUE, TRUE, 0);
+		gtk_widget_show (vbox);
+
+		check_again = gtk_check_button_new_with_mnemonic (
+			_("_Do not ask me again."));
+		gtk_box_pack_start (GTK_BOX (vbox), check_again, TRUE, TRUE, 0);
+		gtk_widget_show (check_again);
+
+		check_always_ignore = gtk_check_button_new_with_mnemonic (
+			_("_Always ignore Reply-To: for mailing lists."));
+		gtk_box_pack_start (
+			GTK_BOX (vbox), check_always_ignore, TRUE, TRUE, 0);
+		gtk_widget_show (check_always_ignore);
+
+		response = gtk_dialog_run (GTK_DIALOG (dialog));
+
+		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check_again)))
+			gconf_client_set_bool (
+				gconf, "/apps/evolution/mail/prompts/list_reply_to", FALSE, NULL);
+
+		gconf_client_set_bool (
+			gconf, "/apps/evolution/mail/composer/ignore_list_reply_to",
+			gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check_always_ignore)),
+			NULL);
+
+		gtk_widget_destroy (dialog);
+
+		if (response == GTK_RESPONSE_NO)
+			mode = REPLY_MODE_FROM;
+		else if (response == GTK_RESPONSE_OK)
+			mode = REPLY_MODE_LIST;
+		else if (response == GTK_RESPONSE_CANCEL)
+			return;
+	}
+
+	e_mail_reader_reply_to_message (reader, message, mode);
 }
 
 static void
 action_mail_reply_sender_cb (GtkAction *action,
                              EMailReader *reader)
 {
-	e_mail_reader_reply_to_message (reader, REPLY_MODE_SENDER);
+	GConfClient *gconf;
+
+	gconf = mail_config_get_gconf_client ();
+	if ((gconf_client_get_bool (gconf, "/apps/evolution/mail/prompts/private_list_reply", NULL) ||
+	     gconf_client_get_bool (gconf, "/apps/evolution/mail/prompts/list_reply_to", NULL)) &&
+	    e_mail_reader_check_state (reader) & E_MAIL_READER_SELECTION_IS_MAILING_LIST) {
+		CamelMimeMessage *message = NULL;
+		EWebView *web_view;
+		EMFormatHTML *formatter;
+
+		formatter = e_mail_reader_get_formatter (reader);
+		web_view = em_format_html_get_web_view (formatter);
+		if (gtk_widget_get_mapped (GTK_WIDGET (web_view)))
+			message = CAMEL_MIME_MESSAGE (EM_FORMAT (formatter)->message);
+
+		if (!message) {
+			CamelFolder *folder;
+			GtkWidget *message_list;
+			gchar *uid;
+
+			folder = e_mail_reader_get_folder (reader);
+			message_list = e_mail_reader_get_message_list (reader);
+
+			uid = MESSAGE_LIST (message_list)->cursor_uid;
+			g_return_if_fail (uid != NULL);
+
+			mail_get_message (
+				folder, uid, action_mail_reply_sender_check,
+				reader, mail_msg_unordered_push);
+			return;
+		}
+		action_mail_reply_sender_check (NULL, NULL, message, reader);
+		return;
+	}
+	e_mail_reader_reply_to_message (reader, NULL, REPLY_MODE_SENDER);
 }
 
 static void
@@ -942,6 +1202,9 @@ action_mail_show_all_headers_cb (GtkToggleAction *action,
 
 	formatter = e_mail_reader_get_formatter (reader);
 
+	if (!formatter)
+		return;
+
 	if (gtk_toggle_action_get_active (action))
 		mode = EM_FORMAT_ALLHEADERS;
 	else
@@ -971,7 +1234,10 @@ action_mail_show_source_cb (GtkAction *action,
 	browser = e_mail_browser_new (shell_backend);
 	reader = E_MAIL_READER (browser);
 	formatter = e_mail_reader_get_formatter (reader);
-	em_format_set_mode (EM_FORMAT (formatter), EM_FORMAT_SOURCE);
+
+	if (formatter)
+		em_format_set_mode (EM_FORMAT (formatter), EM_FORMAT_SOURCE);
+
 	e_mail_reader_set_folder (reader, folder, folder_uri);
 	e_mail_reader_set_message (reader, uids->pdata[0]);
 	gtk_widget_show (browser);
@@ -1418,7 +1684,7 @@ static GtkActionEntry mail_reader_entries[] = {
 	  G_CALLBACK (action_mail_redirect_cb) },
 
 	{ "mail-reply-all",
-	  "mail-reply-all",
+	  NULL,
 	  N_("Reply to _All"),
 	  "<Shift><Control>r",
 	  N_("Compose a reply to all the recipients of the selected message"),
@@ -1441,7 +1707,7 @@ static GtkActionEntry mail_reader_entries[] = {
 	{ "mail-save-as",
 	  GTK_STOCK_SAVE_AS,
 	  N_("_Save as mbox..."),
-	  NULL,
+	  "<Control>s",
 	  N_("Save selected messages as an mbox file"),
 	  G_CALLBACK (action_mail_save_as_cb) },
 
@@ -1538,6 +1804,13 @@ static GtkActionEntry mail_reader_entries[] = {
 	  NULL,
 	  NULL },
 
+	{ "mail-reply-group-menu",
+	  NULL,
+	  N_("_Group Reply"),
+	  NULL,
+	  NULL,
+	  NULL },
+
 	{ "mail-goto-menu",
 	  GTK_STOCK_JUMP_TO,
 	  N_("_Go To"),
@@ -1890,7 +2163,7 @@ mail_reader_message_loaded_cb (CamelFolder *folder,
 		g_clear_error (error);
 	}
 
-	/* We referenced this in the call to mail_get_messagex(). */
+	/* We referenced this in the call to mail_get_messagex (). */
 	g_object_unref (reader);
 
 exit:
@@ -1942,7 +2215,12 @@ mail_reader_message_selected_timeout_cb (EMailReader *reader)
 
 			string = g_strdup_printf (
 				_("Retrieving message '%s'"), cursor_uid);
+#if HAVE_CLUTTER
+			if (!e_shell_get_express_mode (e_shell_get_default ()))
+				e_web_view_load_string (web_view, string);
+#else
 			e_web_view_load_string (web_view, string);
+#endif
 			g_free (string);
 
 			store_async = parent_store->flags & CAMEL_STORE_ASYNC;
@@ -2400,6 +2678,16 @@ mail_reader_update_actions (EMailReader *reader,
 	action = e_mail_reader_get_action (reader, action_name);
 	gtk_action_set_sensitive (action, sensitive);
 
+	action_name = "mail-reply-group";
+	sensitive = have_enabled_account && single_message_selected;
+	action = e_mail_reader_get_action (reader, action_name);
+	gtk_action_set_sensitive (action, sensitive);
+
+	action_name = "mail-reply-group-menu";
+	sensitive = have_enabled_account && any_messages_selected;
+	action = e_mail_reader_get_action (reader, action_name);
+	gtk_action_set_sensitive (action, sensitive);
+
 	action_name = "mail-reply-list";
 	sensitive = have_enabled_account && single_message_selected &&
 		selection_is_mailing_list;
@@ -2481,6 +2769,7 @@ mail_reader_class_init (EMailReaderIface *iface)
 	iface->get_folder_uri = mail_reader_get_folder_uri;
 	iface->set_folder = mail_reader_set_folder;
 	iface->set_message = mail_reader_set_message;
+	iface->open_selected_mail = e_mail_reader_open_selected;
 	iface->update_actions = mail_reader_update_actions;
 
 	g_object_interface_install_property (
@@ -2601,6 +2890,25 @@ e_mail_reader_init (EMailReader *reader)
 	gtk_action_group_add_action_with_accel (
 		action_group, GTK_ACTION (menu_tool_action), "<Control>f");
 
+	/* Likewise the "mail-reply-group" action */
+
+        /* For Translators: "Group Reply" will reply either to a mailing list
+	   (if possible and if that configuration option is enabled), or else
+	   it will reply to all. The word "Group" was chosen because it covers
+	   either of those, without too strongly implying one or the other. */
+	menu_tool_action = e_menu_tool_action_new ("mail-reply-group", _("Group Reply"),
+		_("Reply to the mailing list, or to all recipients"), NULL);
+
+	gtk_action_set_icon_name (
+		GTK_ACTION (menu_tool_action), "mail-reply-all");
+
+	g_signal_connect (
+		menu_tool_action, "activate",
+		G_CALLBACK (action_mail_reply_group_cb), reader);
+
+	gtk_action_group_add_action_with_accel (
+		action_group, GTK_ACTION (menu_tool_action), "<Control>g");
+
 	/* Add the other actions the normal way. */
 
 	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
@@ -2640,6 +2948,10 @@ e_mail_reader_init (EMailReader *reader)
 	action = e_mail_reader_get_action (reader, action_name);
 	g_object_set (action, "is-important", TRUE, NULL);
 
+	action_name = "mail-reply-group";
+	action = e_mail_reader_get_action (reader, action_name);
+	g_object_set (action, "is-important", TRUE, NULL);
+
 	action_name = "mail-next";
 	action = e_mail_reader_get_action (reader, action_name);
 	g_object_set (action, "short-label", _("Next"), NULL);
@@ -2725,6 +3037,57 @@ e_mail_reader_init (EMailReader *reader)
 		G_CALLBACK (mail_reader_destroy), NULL);
 }
 
+void
+e_mail_reader_init_private (EMailReader *reader)
+{
+	EMFormatHTML *formatter;
+	EWebView *web_view;
+	GtkWidget *message_list;
+
+	g_return_if_fail (E_IS_MAIL_READER (reader));
+
+	formatter = e_mail_reader_get_formatter (reader);
+	message_list = e_mail_reader_get_message_list (reader);
+
+	web_view = em_format_html_get_web_view (formatter);
+
+	quark_private = g_quark_from_static_string ("EMailReader-private");
+
+	/* Connect signals. */
+
+	g_signal_connect_swapped (
+		web_view, "key-press-event",
+		G_CALLBACK (mail_reader_key_press_event_cb), reader);
+
+	g_signal_connect_swapped (
+		message_list, "message-selected",
+		G_CALLBACK (mail_reader_message_selected_cb), reader);
+
+	g_signal_connect_swapped (
+		message_list, "message-list-built",
+		G_CALLBACK (mail_reader_emit_folder_loaded), reader);
+
+	g_signal_connect_swapped (
+		message_list, "double-click",
+		G_CALLBACK (mail_reader_double_click_cb), reader);
+
+	g_signal_connect_swapped (
+		message_list, "key-press",
+		G_CALLBACK (mail_reader_key_press_cb), reader);
+
+	g_signal_connect_swapped (
+		message_list, "selection-change",
+		G_CALLBACK (e_mail_reader_changed), reader);
+
+	g_object_set_qdata_full (
+		G_OBJECT (reader), quark_private,
+		g_slice_new0 (EMailReaderPrivate),
+		(GDestroyNotify) mail_reader_private_free);
+	g_signal_connect (
+		reader, "destroy",
+		G_CALLBACK (mail_reader_destroy), NULL);
+}
+
 void
 e_mail_reader_changed (EMailReader *reader)
 {
@@ -2752,7 +3115,6 @@ e_mail_reader_check_state (EMailReader *reader)
 	gboolean has_undeleted = FALSE;
 	gboolean has_unimportant = FALSE;
 	gboolean has_unread = FALSE;
-	gboolean have_enabled_account = FALSE;
 	gboolean drafts_or_outbox;
 	gboolean store_supports_vjunk = FALSE;
 	gboolean is_mailing_list;
@@ -3070,7 +3432,7 @@ e_mail_reader_set_folder (EMailReader *reader,
 	iface->set_folder (reader, folder, folder_uri);
 }
 
-/* Helper for e_mail_reader_set_folder_uri() */
+/* Helper for e_mail_reader_set_folder_uri () */
 static void
 mail_reader_got_folder_cb (gchar *folder_uri,
                            CamelFolder *folder,
@@ -3108,6 +3470,19 @@ e_mail_reader_set_message (EMailReader *reader,
 	iface->set_message (reader, uid);
 }
 
+guint
+e_mail_reader_open_selected_mail (EMailReader *reader)
+{
+	EMailReaderIface *iface;
+
+	g_return_val_if_fail (E_IS_MAIL_READER (reader), 0);
+
+	iface = E_MAIL_READER_GET_IFACE (reader);
+	g_return_val_if_fail (iface->open_selected_mail != NULL, 0);
+
+	return iface->open_selected_mail (reader);
+}
+
 gboolean
 e_mail_reader_get_group_by_threads (EMailReader *reader)
 {
