@@ -552,7 +552,7 @@ struct _save_draft_info {
 };
 
 static void
-composer_set_no_change (EMsgComposer *composer, gboolean drop_undo, gboolean editor_changed)
+composer_set_no_change (EMsgComposer *composer)
 {
 	GtkhtmlEditor *editor;
 
@@ -560,11 +560,8 @@ composer_set_no_change (EMsgComposer *composer, gboolean drop_undo, gboolean edi
 
 	editor = GTKHTML_EDITOR (composer);
 
-	if (drop_undo)
-		gtkhtml_editor_drop_undo (editor);
-
-	if (editor_changed)
-		gtkhtml_editor_set_changed (editor, FALSE);
+	gtkhtml_editor_drop_undo (editor);
+	gtkhtml_editor_set_changed (editor, FALSE);
 }
 
 static void
@@ -751,7 +748,7 @@ em_utils_compose_new_message (const gchar *fromuri)
 	if (composer == NULL)
 		return;
 
-	composer_set_no_change (E_MSG_COMPOSER (composer), TRUE, TRUE);
+	composer_set_no_change (E_MSG_COMPOSER (composer));
 
 	gtk_widget_show (composer);
 }
@@ -782,7 +779,7 @@ em_utils_compose_new_message_with_mailto (const gchar *url, const gchar *fromuri
 	    && (account = mail_config_get_account_by_source_url(fromuri)))
 		e_composer_header_table_set_account_name (table, account->name);
 
-	composer_set_no_change (composer, TRUE, url == NULL);
+	composer_set_no_change (composer);
 
 	gtk_window_present (GTK_WINDOW (composer));
 
@@ -913,15 +910,15 @@ traverse_parts (GSList *clues, CamelMimeMessage *message, CamelDataWrapper *cont
 
 		byte_array = g_byte_array_new ();
 		stream = camel_stream_mem_new_with_byte_array (byte_array);
-		camel_data_wrapper_decode_to_stream (content, stream);
+		camel_data_wrapper_decode_to_stream (content, stream, NULL);
 
 		str = g_strndup ((gchar *) byte_array->data, byte_array->len);
 		g_object_unref (stream);
 
 		if (replace_variables (clues, message, &str)) {
 			stream = camel_stream_mem_new_with_buffer (str, strlen (str));
-			camel_stream_reset (stream);
-			camel_data_wrapper_construct_from_stream (content, stream);
+			camel_stream_reset (stream, NULL);
+			camel_data_wrapper_construct_from_stream (content, stream, NULL);
 			g_object_unref (stream);
 		}
 
@@ -961,7 +958,7 @@ edit_message (CamelMimeMessage *message, CamelFolder *drafts, const gchar *uid)
 		emcs_set_drafts_info (emcs, drafts, uid);
 	}
 
-	composer_set_no_change (composer, TRUE, TRUE);
+	composer_set_no_change (composer);
 
 	gtk_widget_show (GTK_WIDGET (composer));
 
@@ -1121,7 +1118,7 @@ forward_attached (CamelFolder *folder, GPtrArray *uids, GPtrArray *messages, Cam
 	if (uids)
 		setup_forward_attached_callbacks (composer, folder, uids);
 
-	composer_set_no_change (composer, TRUE, TRUE);
+	composer_set_no_change (composer);
 
 	gtk_widget_show (GTK_WIDGET (composer));
 
@@ -1209,7 +1206,7 @@ forward_non_attached (CamelFolder *folder, GPtrArray *uids, GPtrArray *messages,
 				}
 
 				emu_update_composers_security (composer, validity_found);
-				composer_set_no_change (composer, TRUE, TRUE);
+				composer_set_no_change (composer);
 				gtk_widget_show (GTK_WIDGET (composer));
 			}
 			g_free (text);
@@ -1387,7 +1384,7 @@ em_utils_redirect_message (CamelMimeMessage *message)
 
 	gtk_widget_show (GTK_WIDGET (composer));
 
-	composer_set_no_change (composer, TRUE, TRUE);
+	composer_set_no_change (composer);
 }
 
 static void
@@ -1417,13 +1414,13 @@ em_utils_redirect_message_by_uid (CamelFolder *folder, const gchar *uid)
 }
 
 static void
-emu_handle_receipt_message(CamelFolder *folder, const gchar *uid, CamelMimeMessage *msg, gpointer data, CamelException *ex)
+emu_handle_receipt_message(CamelFolder *folder, const gchar *uid, CamelMimeMessage *msg, gpointer data, GError **error)
 {
 	if (msg)
 		em_utils_handle_receipt(folder, uid, msg);
 
 	/* we dont care really if we can't get the message */
-	camel_exception_clear(ex);
+	g_clear_error (error);
 }
 
 /* Message disposition notifications, rfc 2298 */
@@ -1541,7 +1538,7 @@ em_utils_send_receipt (CamelFolder *folder, CamelMimeMessage *message)
 	/* Translators: First %s is an email address, second %s is the subject of the email, third %s is the date */
 			     _("Your message to %s about \"%s\" on %s has been read."),
 			     self_address, message_subject, message_date);
-	camel_data_wrapper_construct_from_stream (receipt_text, stream);
+	camel_data_wrapper_construct_from_stream (receipt_text, stream, NULL);
 	g_object_unref (stream);
 
 	part = camel_mime_part_new ();
@@ -1569,7 +1566,7 @@ em_utils_send_receipt (CamelFolder *folder, CamelMimeMessage *message)
 			     "Original-Message-ID: %s\n"
 			     "Disposition: manual-action/MDN-sent-manually; displayed\n",
 			     ua, recipient, message_id);
-	camel_data_wrapper_construct_from_stream (receipt_data, stream);
+	camel_data_wrapper_construct_from_stream (receipt_data, stream, NULL);
 	g_object_unref (stream);
 
 	g_free (ua);
@@ -1739,37 +1736,6 @@ reply_get_composer (CamelMimeMessage *message, EAccount *account,
 	return composer;
 }
 
-static void
-get_reply_sender (CamelMimeMessage *message, CamelInternetAddress *to, CamelNNTPAddress *postto)
-{
-	CamelInternetAddress *reply_to;
-	const gchar *name, *addr, *posthdr;
-	gint i;
-
-	/* check whether there is a 'Newsgroups: ' header in there */
-	if (postto
-	    && ((posthdr = camel_medium_get_header((CamelMedium *)message, "Followup-To"))
-		 || (posthdr = camel_medium_get_header((CamelMedium *)message, "Newsgroups")))) {
-		camel_address_decode((CamelAddress *)postto, posthdr);
-		return;
-	}
-
-	reply_to = camel_mime_message_get_reply_to (message);
-	if (!reply_to)
-		reply_to = camel_mime_message_get_from (message);
-
-	if (reply_to) {
-		for (i = 0; camel_internet_address_get (reply_to, i, &name, &addr); i++)
-			camel_internet_address_add (to, name, addr);
-	}
-}
-
-void
-em_utils_get_reply_sender (CamelMimeMessage *message, CamelInternetAddress *to, CamelNNTPAddress *postto)
-{
-	get_reply_sender (message, to, postto);
-}
-
 static gboolean
 get_reply_list (CamelMimeMessage *message, CamelInternetAddress *to)
 {
@@ -1810,6 +1776,113 @@ get_reply_list (CamelMimeMessage *message, CamelInternetAddress *to)
 	return TRUE;
 }
 
+gboolean
+em_utils_is_munged_list_message(CamelMimeMessage *message)
+{
+	CamelInternetAddress *reply_to, *list;
+	gboolean result = FALSE;
+
+	reply_to = camel_mime_message_get_reply_to (message);
+	if (reply_to) {
+		list = camel_internet_address_new ();
+
+		if (get_reply_list (message, list) &&
+		    camel_address_length (CAMEL_ADDRESS(list)) == camel_address_length (CAMEL_ADDRESS(reply_to))) {
+			gint i;
+			const gchar *r_name, *r_addr;
+			const gchar *l_name, *l_addr;
+
+			for (i = 0; i < camel_address_length (CAMEL_ADDRESS(list)); i++) {
+				if (!camel_internet_address_get (reply_to, i, &r_name, &r_addr))
+					break;
+				if (!camel_internet_address_get (list, i, &l_name, &l_addr))
+					break;
+				if (strcmp (l_addr, r_addr))
+					break;
+			}
+			if (i == camel_address_length (CAMEL_ADDRESS(list)))
+				result = TRUE;
+		}
+		g_object_unref (list);
+	}
+	return result;
+}
+
+static CamelInternetAddress *
+get_reply_to (CamelMimeMessage *message)
+{
+	CamelInternetAddress *reply_to;
+
+	reply_to = camel_mime_message_get_reply_to (message);
+	if (reply_to) {
+		GConfClient *gconf;
+		gboolean ignore_list_reply_to;
+
+		gconf = mail_config_get_gconf_client ();
+		ignore_list_reply_to = gconf_client_get_bool (gconf,
+					"/apps/evolution/mail/composer/ignore_list_reply_to", NULL);
+
+		if (ignore_list_reply_to && em_utils_is_munged_list_message (message))
+			reply_to = NULL;
+	}
+	if (!reply_to)
+		reply_to = camel_mime_message_get_from (message);
+
+	return reply_to;
+}
+
+static void
+get_reply_sender (CamelMimeMessage *message, CamelInternetAddress *to, CamelNNTPAddress *postto)
+{
+	CamelInternetAddress *reply_to;
+	const gchar *name, *addr, *posthdr;
+	gint i;
+
+	/* check whether there is a 'Newsgroups: ' header in there */
+	if (postto
+	    && ((posthdr = camel_medium_get_header((CamelMedium *)message, "Followup-To"))
+		 || (posthdr = camel_medium_get_header((CamelMedium *)message, "Newsgroups")))) {
+		camel_address_decode((CamelAddress *)postto, posthdr);
+		return;
+	}
+
+	reply_to = get_reply_to (message);
+
+	if (reply_to) {
+		for (i = 0; camel_internet_address_get (reply_to, i, &name, &addr); i++)
+			camel_internet_address_add (to, name, addr);
+	}
+}
+
+void
+em_utils_get_reply_sender (CamelMimeMessage *message, CamelInternetAddress *to, CamelNNTPAddress *postto)
+{
+	get_reply_sender (message, to, postto);
+}
+
+static void
+get_reply_from (CamelMimeMessage *message, CamelInternetAddress *to, CamelNNTPAddress *postto)
+{
+	CamelInternetAddress *from;
+	const gchar *name, *addr, *posthdr;
+	gint i;
+
+	/* check whether there is a 'Newsgroups: ' header in there */
+	if (postto
+	    && ((posthdr = camel_medium_get_header((CamelMedium *)message, "Followup-To"))
+		 || (posthdr = camel_medium_get_header((CamelMedium *)message, "Newsgroups")))) {
+		camel_address_decode((CamelAddress *)postto, posthdr);
+		return;
+	}
+
+	from = camel_mime_message_get_from (message);
+
+	if (from) {
+		for (i = 0; camel_internet_address_get (from, i, &name, &addr); i++)
+			camel_internet_address_add (to, name, addr);
+	}
+}
+
 static void
 concat_unique_addrs (CamelInternetAddress *dest, CamelInternetAddress *src, GHashTable *rcpt_hash)
 {
@@ -1842,10 +1915,7 @@ get_reply_all (CamelMimeMessage *message, CamelInternetAddress *to, CamelInterne
 
 	rcpt_hash = em_utils_generate_account_hash ();
 
-	reply_to = camel_mime_message_get_reply_to (message);
-	if (!reply_to)
-		reply_to = camel_mime_message_get_from (message);
-
+	reply_to = get_reply_to(message);
 	to_addrs = camel_mime_message_get_recipients (message, CAMEL_RECIPIENT_TYPE_TO);
 	cc_addrs = camel_mime_message_get_recipients (message, CAMEL_RECIPIENT_TYPE_CC);
 
@@ -2168,9 +2238,12 @@ reply_to_message(CamelFolder *folder, const gchar *uid, CamelMimeMessage *messag
 {
 	struct _reply_data *rd = user_data;
 
-	if (message != NULL)
+	if (message != NULL) {
+		/* get_message_free() will also unref the message, so we need
+		   an extra ref for em_utils_reply_to_message() to drop. */
+		g_object_ref(message);
 		em_utils_reply_to_message(folder, uid, message, rd->mode, rd->source);
-
+	}
 	if (rd->source)
 		g_object_unref(rd->source);
 	g_free(rd);
@@ -2191,7 +2264,7 @@ reply_to_message(CamelFolder *folder, const gchar *uid, CamelMimeMessage *messag
  *
  * If @message is non null, then it is used directly, @folder and @uid
  * may be supplied in order to update the message flags once it has
- * been replied to.
+ * been replied to. Note that @message will be unreferenced on completion.
  **/
 EMsgComposer *
 em_utils_reply_to_message(CamelFolder *folder, const gchar *uid, CamelMimeMessage *message, gint mode, EMFormat *source)
@@ -2224,6 +2297,12 @@ em_utils_reply_to_message(CamelFolder *folder, const gchar *uid, CamelMimeMessag
 	flags = CAMEL_MESSAGE_ANSWERED | CAMEL_MESSAGE_SEEN;
 
 	switch (mode) {
+	case REPLY_MODE_FROM:
+		if (folder)
+			postto = camel_nntp_address_new();
+
+		get_reply_from (message, to, postto);
+		break;
 	case REPLY_MODE_SENDER:
 		if (folder)
 			postto = camel_nntp_address_new();
@@ -2254,10 +2333,11 @@ em_utils_reply_to_message(CamelFolder *folder, const gchar *uid, CamelMimeMessag
 
 	composer_set_body (composer, message, source);
 
+	g_object_unref(message);
 	emcs = g_object_get_data (G_OBJECT (composer), "emcs");
 	emcs_set_folder_info (emcs, folder, uid, flags, flags);
 
-	composer_set_no_change (composer, TRUE, TRUE);
+	composer_set_no_change (composer);
 
 	gtk_widget_show (GTK_WIDGET (composer));
 
