@@ -48,6 +48,9 @@
 #include "e-util/e-util-private.h"
 #include "e-util/e-util.h"
 #include "e-util/e-extensible.h"
+#include "misc/e-web-view.h"
+
+#include <shell/e-shell.h>
 
 #include <gtkhtml/gtkhtml.h>
 #include <gtkhtml/gtkhtml-stream.h>
@@ -77,6 +80,8 @@ struct _EMFormatHTMLCache {
 };
 
 struct _EMFormatHTMLPrivate {
+	EWebView *web_view;
+
 	CamelMimeMessage *last_part;	/* not reffed, DO NOT dereference */
 	volatile gint format_id;		/* format thread id */
 	guint format_timeout_id;
@@ -109,7 +114,8 @@ enum {
 	PROP_ONLY_LOCAL_PHOTOS,
 	PROP_SHOW_SENDER_PHOTO,
 	PROP_SHOW_REAL_DATE,
-	PROP_TEXT_COLOR
+	PROP_TEXT_COLOR,
+	PROP_WEB_VIEW
 };
 
 static void efh_url_requested(GtkHTML *html, const gchar *url, GtkHTMLStream *handle, EMFormatHTML *efh);
@@ -156,7 +162,7 @@ efh_format_exec (struct _format_msg *m)
 	gint cancelled = FALSE;
 	CamelURL *base;
 
-	if (m->format->html == NULL)
+	if (m->format->priv->web_view == NULL)
 		return;
 
 	format = EM_FORMAT (m->format);
@@ -200,7 +206,7 @@ efh_format_exec (struct _format_msg *m)
 				(CamelMimePart *) m->message, handle, FALSE);
 	}
 
-	camel_stream_flush((CamelStream *)m->estream);
+	camel_stream_flush((CamelStream *)m->estream, NULL);
 
 	puri_level = format->pending_uri_level;
 	base = format->base;
@@ -213,7 +219,7 @@ efh_format_exec (struct _format_msg *m)
 
 			/* This is an implicit check to see if the gtkhtml has been destroyed */
 			if (!cancelled)
-				cancelled = m->format->html == NULL;
+				cancelled = m->format->priv->web_view == NULL;
 
 			/* Now do an explicit check for user cancellation */
 			if (!cancelled)
@@ -240,8 +246,10 @@ efh_format_exec (struct _format_msg *m)
 			/* Closing this base stream can queue more jobs, so we need
 			   to check the list again after we've finished */
 			d(printf("out of jobs, closing root stream\n"));
-			camel_stream_write_string((CamelStream *)m->estream, "</body>\n</html>\n");
-			camel_stream_close((CamelStream *)m->estream);
+			camel_stream_write_string (
+				(CamelStream *) m->estream,
+				"</body>\n</html>\n", NULL);
+			camel_stream_close((CamelStream *)m->estream, NULL);
 			g_object_unref (m->estream);
 			m->estream = NULL;
 		}
@@ -270,7 +278,7 @@ efh_format_free (struct _format_msg *m)
 	d(printf("formatter freed\n"));
 	g_object_unref(m->format);
 	if (m->estream) {
-		camel_stream_close((CamelStream *)m->estream);
+		camel_stream_close((CamelStream *)m->estream, NULL);
 		g_object_unref (m->estream);
 	}
 	if (m->folder)
@@ -296,8 +304,11 @@ efh_format_timeout(struct _format_msg *m)
 	GtkHTMLStream *hstream;
 	EMFormatHTML *efh = m->format;
 	struct _EMFormatHTMLPrivate *p = efh->priv;
+	EWebView *web_view;
 
-	if (m->format->html == NULL) {
+	web_view = em_format_html_get_web_view (m->format);
+
+	if (web_view == NULL) {
 		mail_msg_unref(m);
 		return FALSE;
 	}
@@ -326,21 +337,25 @@ efh_format_timeout(struct _format_msg *m)
 	}
 
 	if (m->message == NULL) {
-		hstream = gtk_html_begin(efh->html);
+		hstream = gtk_html_begin (GTK_HTML (web_view));
 		gtk_html_stream_close(hstream, GTK_HTML_STREAM_OK);
 		mail_msg_unref(m);
 		p->last_part = NULL;
 	} else {
 		efh->state = EM_FORMAT_HTML_STATE_RENDERING;
-
+#if HAVE_CLUTTER
+		if (p->last_part != m->message && !e_shell_get_express_mode(e_shell_get_default())) {
+#else
 		if (p->last_part != m->message) {
-			hstream = gtk_html_begin (efh->html);
+#endif
+			hstream = gtk_html_begin (GTK_HTML (web_view));
 			gtk_html_stream_printf (hstream, "<h5>%s</h5>", _("Formatting Message..."));
 			gtk_html_stream_close (hstream, GTK_HTML_STREAM_OK);
 		}
 
 		hstream = NULL;
-		m->estream = (EMHTMLStream *)em_html_stream_new(efh->html, hstream);
+		m->estream = (EMHTMLStream *)em_html_stream_new (
+			GTK_HTML (web_view), hstream);
 
 		if (p->last_part == m->message) {
 			em_html_stream_set_flags (m->estream,
@@ -385,9 +400,9 @@ efh_gtkhtml_destroy(GtkHTML *html, EMFormatHTML *efh)
 	if (efh->priv->format_id != -1)
 		mail_msg_cancel(efh->priv->format_id);
 
-	if (efh->html != NULL) {
-		g_object_unref (efh->html);
-		efh->html = NULL;
+	if (efh->priv->web_view != NULL) {
+		g_object_unref (efh->priv->web_view);
+		efh->priv->web_view = NULL;
 	}
 }
 
@@ -573,6 +588,12 @@ efh_get_property (GObject *object,
 				&color);
 			g_value_set_boxed (value, &color);
 			return;
+
+		case PROP_WEB_VIEW:
+			g_value_set_object (
+				value, em_format_html_get_web_view (
+				EM_FORMAT_HTML (object)));
+			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -586,7 +607,7 @@ efh_finalize (GObject *object)
 	/* FIXME: check for leaked stuff */
 
 	em_format_html_clear_pobject (efh);
-	efh_gtkhtml_destroy (efh->html, efh);
+	efh_gtkhtml_destroy (GTK_HTML (efh->priv->web_view), efh);
 
 	g_hash_table_destroy (efh->priv->text_inline_parts);
 
@@ -606,7 +627,7 @@ efh_format_clone (EMFormat *emf,
 
 	/* How to sub-class ?  Might need to adjust api ... */
 
-	if (efh->html == NULL)
+	if (efh->priv->web_view == NULL)
 		return;
 
 	d(printf("efh_format called\n"));
@@ -681,11 +702,11 @@ efh_format_source (EMFormat *emf,
 		CAMEL_STREAM_FILTER (filtered_stream), filter);
 	g_object_unref (filter);
 
-	camel_stream_write_string (stream, "<table><tr><td><tt>");
+	camel_stream_write_string (stream, "<table><tr><td><tt>", NULL);
 	em_format_format_text (emf, (CamelStream *) filtered_stream, dw);
 	g_object_unref (filtered_stream);
 
-	camel_stream_write_string(stream, "</tt></td></tr></table>");
+	camel_stream_write_string(stream, "</tt></td></tr></table>", NULL);
 }
 
 static void
@@ -706,18 +727,20 @@ efh_format_attachment (EMFormat *emf,
 		"<table width=10 cellspacing=0 cellpadding=0>"
 		"<tr><td></td></tr></table></td>"
 		"<td><table width=3 cellspacing=0 cellpadding=0>"
-		"<tr><td></td></tr></table></td><td><font size=-1>\n");
+		"<tr><td></td></tr></table></td><td><font size=-1>\n",
+		NULL);
 
 	/* output some info about it */
 	text = em_format_describe_part(part, mime_type);
 	html = camel_text_to_html (
 		text, ((EMFormatHTML *)emf)->text_html_flags &
 		CAMEL_MIME_FILTER_TOHTML_CONVERT_URLS, 0);
-	camel_stream_write_string (stream, html);
+	camel_stream_write_string (stream, html, NULL);
 	g_free (html);
 	g_free (text);
 
-	camel_stream_write_string (stream, "</font></td></tr><tr></table>");
+	camel_stream_write_string (
+		stream, "</font></td></tr><tr></table>", NULL);
 
 	if (handle && em_format_is_inline (emf, emf->part_id->str, part, handle))
 		handle->handler (emf, stream, part, handle, FALSE);
@@ -743,7 +766,7 @@ efh_class_init (EMFormatHTMLClass *class)
 {
 	GObjectClass *object_class;
 	EMFormatClass *format_class;
-	gchar *pathname;
+	const gchar *user_cache_dir;
 
 	parent_class = g_type_class_peek_parent (class);
 	g_type_class_add_private (class, sizeof (EMFormatHTMLPrivate));
@@ -761,7 +784,7 @@ efh_class_init (EMFormatHTMLClass *class)
 	format_class->format_secure = efh_format_secure;
 	format_class->busy = efh_busy;
 
-	class->html_widget_type = GTK_TYPE_HTML;
+	class->html_widget_type = E_TYPE_WEB_VIEW;
 
 	g_object_class_install_property (
 		object_class,
@@ -879,22 +902,30 @@ efh_class_init (EMFormatHTMLClass *class)
 			GDK_TYPE_COLOR,
 			G_PARAM_READWRITE));
 
+	g_object_class_install_property (
+		object_class,
+		PROP_WEB_VIEW,
+		g_param_spec_object (
+			"web-view",
+			"Web View",
+			NULL,
+			E_TYPE_WEB_VIEW,
+			G_PARAM_READABLE));
+
 	/* cache expiry - 2 hour access, 1 day max */
-	pathname = g_build_filename (
-		e_get_user_data_dir (), "cache", NULL);
-	emfh_http_cache = camel_data_cache_new (pathname, NULL);
+	user_cache_dir = e_get_user_cache_dir ();
+	emfh_http_cache = camel_data_cache_new (user_cache_dir, NULL);
 	if (emfh_http_cache) {
 		camel_data_cache_set_expire_age(emfh_http_cache, 24*60*60);
 		camel_data_cache_set_expire_access(emfh_http_cache, 2*60*60);
 	}
-	g_free (pathname);
 }
 
 static void
 efh_init (EMFormatHTML *efh,
           EMFormatHTMLClass *class)
 {
-	GtkHTML *html;
+	EWebView *web_view;
 	GdkColor *color;
 
 	efh->priv = EM_FORMAT_HTML_GET_PRIVATE (efh);
@@ -908,19 +939,21 @@ efh_init (EMFormatHTML *efh,
 		(GDestroyNotify) NULL,
 		(GDestroyNotify) efh_free_cache);
 
-	html = g_object_new (class->html_widget_type, NULL);
-	efh->html = g_object_ref_sink (html);
+	web_view = g_object_new (class->html_widget_type, NULL);
+	efh->priv->web_view = g_object_ref_sink (web_view);
 
-	gtk_html_set_blocking (html, FALSE);
-	gtk_html_set_caret_first_focus_anchor (html, EFM_MESSAGE_START_ANAME);
-	gtk_html_set_default_content_type (html, "text/html; charset=utf-8");
-	gtk_html_set_editable (html, FALSE);
+	gtk_html_set_blocking (GTK_HTML (web_view), FALSE);
+	gtk_html_set_caret_first_focus_anchor (
+		GTK_HTML (web_view), EFM_MESSAGE_START_ANAME);
+	gtk_html_set_default_content_type (
+		GTK_HTML (web_view), "text/html; charset=utf-8");
+	e_web_view_set_editable (web_view, FALSE);
 
 	g_signal_connect (
-		html, "url-requested",
+		web_view, "url-requested",
 		G_CALLBACK (efh_url_requested), efh);
 	g_signal_connect (
-		html, "object-requested",
+		web_view, "object-requested",
 		G_CALLBACK (efh_object_requested), efh);
 
 	color = &efh->priv->colors[EM_FORMAT_HTML_COLOR_BODY];
@@ -988,6 +1021,14 @@ em_format_html_get_type (void)
 	return type;
 }
 
+EWebView *
+em_format_html_get_web_view (EMFormatHTML *efh)
+{
+	g_return_val_if_fail (EM_IS_FORMAT_HTML (efh), NULL);
+
+	return efh->priv->web_view;
+}
+
 void
 em_format_html_load_images (EMFormatHTML *efh)
 {
@@ -1181,12 +1222,12 @@ em_format_html_file_part(EMFormatHTML *efh, const gchar *mime_type, const gchar
 	CamelDataWrapper *dw;
 	gchar *basename;
 
-	stream = camel_stream_fs_new_with_name(filename, O_RDONLY, 0);
+	stream = camel_stream_fs_new_with_name(filename, O_RDONLY, 0, NULL);
 	if (stream == NULL)
 		return NULL;
 
 	dw = camel_data_wrapper_new();
-	camel_data_wrapper_construct_from_stream(dw, stream);
+	camel_data_wrapper_construct_from_stream(dw, stream, NULL);
 	g_object_unref (stream);
 	if (mime_type)
 		camel_data_wrapper_set_mime_type(dw, mime_type);
@@ -1402,7 +1443,7 @@ static void emfh_gethttp(struct _EMFormatHTMLJob *job, gint cancelled)
 			break;
 		}
 		/* FIXME: progress reporting in percentage, can we get the length always?  do we care? */
-		n = camel_stream_read(instream, buffer, sizeof (buffer));
+		n = camel_stream_read(instream, buffer, sizeof (buffer), NULL);
 		if (n > 0) {
 			nread += n;
 			/* If we didn't get a valid Content-Length header, do not try to calculate percentage */
@@ -1411,18 +1452,18 @@ static void emfh_gethttp(struct _EMFormatHTMLJob *job, gint cancelled)
 				camel_operation_progress(NULL, pc_complete);
 			}
 			d(printf("  read %d bytes\n", n));
-			if (costream && camel_stream_write (costream, buffer, n) == -1) {
+			if (costream && camel_stream_write (costream, buffer, n, NULL) == -1) {
 				n = -1;
 				break;
 			}
 
-			camel_stream_write(job->stream, buffer, n);
+			camel_stream_write(job->stream, buffer, n, NULL);
 		}
 	} while (n>0);
 
 	/* indicates success */
 	if (n == 0)
-		camel_stream_close(job->stream);
+		camel_stream_close(job->stream, NULL);
 
 	if (costream) {
 		/* do not store broken files in a cache */
@@ -1499,6 +1540,8 @@ efh_url_requested(GtkHTML *html, const gchar *url, GtkHTMLStream *handle, EMForm
 		job->stream = em_html_stream_new(html, handle);
 		em_format_html_job_queue(efh, job);
 	}
+
+	g_signal_stop_emission_by_name (html, "url-requested");
 }
 
 static gboolean
@@ -1675,8 +1718,9 @@ efh_text_plain (EMFormatHTML *efh,
 		camel_stream_filter_add (
 			CAMEL_STREAM_FILTER (filtered_stream),
 			CAMEL_MIME_FILTER (inline_filter));
-		camel_data_wrapper_write_to_stream(dw, (CamelStream *)filtered_stream);
-		camel_stream_close((CamelStream *)filtered_stream);
+		camel_data_wrapper_decode_to_stream (
+			dw, (CamelStream *)filtered_stream, NULL);
+		camel_stream_close((CamelStream *)filtered_stream, NULL);
 		g_object_unref (filtered_stream);
 
 		mp = em_inline_filter_get_multipart(inline_filter);
@@ -1719,11 +1763,12 @@ efh_text_plain (EMFormatHTML *efh,
 				e_color_to_value (
 					&efh->priv->colors[
 					EM_FORMAT_HTML_COLOR_TEXT]));
-			camel_stream_write_string(stream, "<tt>\n" EFH_MESSAGE_START);
+			camel_stream_write_string (
+				stream, "<tt>\n" EFH_MESSAGE_START, NULL);
 			em_format_format_text((EMFormat *)efh, (CamelStream *)filtered_stream, (CamelDataWrapper *)newpart);
-			camel_stream_flush((CamelStream *)filtered_stream);
-			camel_stream_write_string(stream, "</tt>\n");
-			camel_stream_write_string(stream, "</div>\n");
+			camel_stream_flush((CamelStream *)filtered_stream, NULL);
+			camel_stream_write_string (stream, "</tt>\n", NULL);
+			camel_stream_write_string (stream, "</div>\n", NULL);
 		} else {
 			g_string_append_printf(((EMFormat *)efh)->part_id, ".inline.%d", i);
 			em_format_part((EMFormat *)efh, stream, newpart);
@@ -1743,9 +1788,11 @@ efh_text_enriched(EMFormatHTML *efh, CamelStream *stream, CamelMimePart *part, E
 
 	if (!strcmp(info->mime_type, "text/richtext")) {
 		flags = CAMEL_MIME_FILTER_ENRICHED_IS_RICHTEXT;
-		camel_stream_write_string( stream, "\n<!-- text/richtext -->\n");
+		camel_stream_write_string (
+			stream, "\n<!-- text/richtext -->\n", NULL);
 	} else {
-		camel_stream_write_string( stream, "\n<!-- text/enriched -->\n");
+		camel_stream_write_string (
+			stream, "\n<!-- text/enriched -->\n", NULL);
 	}
 
 	enriched = camel_mime_filter_enriched_new(flags);
@@ -1769,7 +1816,7 @@ efh_text_enriched(EMFormatHTML *efh, CamelStream *stream, CamelMimePart *part, E
 	em_format_format_text((EMFormat *)efh, (CamelStream *)filtered_stream, (CamelDataWrapper *)part);
 
 	g_object_unref (filtered_stream);
-	camel_stream_write_string(stream, "</div>");
+	camel_stream_write_string (stream, "</div>", NULL);
 }
 
 static void
@@ -1963,19 +2010,19 @@ efh_message_deliverystatus(EMFormatHTML *efh, CamelStream *stream, CamelMimePart
 		CAMEL_STREAM_FILTER (filtered_stream), html_filter);
 	g_object_unref (html_filter);
 
-	camel_stream_write_string(stream, "<tt>\n" EFH_MESSAGE_START);
+	camel_stream_write_string (stream, "<tt>\n" EFH_MESSAGE_START, NULL);
 	em_format_format_text((EMFormat *)efh, (CamelStream *)filtered_stream, (CamelDataWrapper *)part);
-	camel_stream_flush((CamelStream *)filtered_stream);
-	camel_stream_write_string(stream, "</tt>\n");
+	camel_stream_flush((CamelStream *)filtered_stream, NULL);
+	camel_stream_write_string (stream, "</tt>\n", NULL);
 
-	camel_stream_write_string(stream, "</div>");
+	camel_stream_write_string (stream, "</div>", NULL);
 }
 
 static void
 emfh_write_related(EMFormat *emf, CamelStream *stream, EMFormatPURI *puri)
 {
 	em_format_format_content(emf, stream, puri->part);
-	camel_stream_close(stream);
+	camel_stream_close(stream, NULL);
 }
 
 static void
@@ -2086,7 +2133,7 @@ efh_multipart_related(EMFormat *emf, CamelStream *stream, CamelMimePart *part, c
 	g_string_append_printf(emf->part_id, "related.%d", displayid);
 	em_format_part(emf, stream, display_part);
 	g_string_truncate(emf->part_id, partidlen);
-	camel_stream_flush(stream);
+	camel_stream_flush(stream, NULL);
 
 	/* queue a job to check for un-referenced parts to add as attachments */
 	job = em_format_html_job_new((EMFormatHTML *)emf, emfh_multipart_related_check, NULL);
@@ -2103,8 +2150,8 @@ efh_write_image(EMFormat *emf, CamelStream *stream, EMFormatPURI *puri)
 	CamelDataWrapper *dw = camel_medium_get_content ((CamelMedium *)puri->part);
 
 	d(printf("writing image '%s'\n", puri->cid));
-	camel_data_wrapper_decode_to_stream(dw, stream);
-	camel_stream_close(stream);
+	camel_data_wrapper_decode_to_stream(dw, stream, NULL);
+	camel_stream_close(stream, NULL);
 }
 
 static void
