@@ -171,7 +171,7 @@ memo_shell_sidebar_backend_error_cb (EMemoShellSidebar *memo_shell_sidebar,
 
 static void
 memo_shell_sidebar_client_opened_cb (EMemoShellSidebar *memo_shell_sidebar,
-                                     ECalendarStatus status,
+                                     const GError *error,
                                      ECal *client)
 {
 	EShellView *shell_view;
@@ -183,12 +183,14 @@ memo_shell_sidebar_client_opened_cb (EMemoShellSidebar *memo_shell_sidebar,
 	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
 	shell_window = e_shell_view_get_shell_window (shell_view);
 
-	if (status == E_CALENDAR_STATUS_AUTHENTICATION_FAILED ||
-		status == E_CALENDAR_STATUS_AUTHENTICATION_REQUIRED)
+	if (g_error_matches (error, E_CALENDAR_ERROR,
+		E_CALENDAR_STATUS_AUTHENTICATION_FAILED) ||
+	    g_error_matches (error, E_CALENDAR_ERROR,
+		E_CALENDAR_STATUS_AUTHENTICATION_REQUIRED))
 		e_auth_cal_forget_password (client);
 
 	/* Handle errors. */
-	switch (status) {
+	switch (error ? error->code : E_CALENDAR_STATUS_OK) {
 		case E_CALENDAR_STATUS_OK:
 			break;
 
@@ -207,13 +209,20 @@ memo_shell_sidebar_client_opened_cb (EMemoShellSidebar *memo_shell_sidebar,
 			/* fall through */
 
 		default:
+			if (error->code != E_CALENDAR_STATUS_REPOSITORY_OFFLINE) {
+				e_alert_run_dialog_for_args (
+					GTK_WINDOW (shell_window),
+					"calendar:failed-open-memos",
+					error->message, NULL);
+			}
+
 			e_memo_shell_sidebar_remove_source (
 				memo_shell_sidebar,
 				e_cal_get_source (client));
 			return;
 	}
 
-	g_assert (status == E_CALENDAR_STATUS_OK);
+	g_assert (error == NULL);
 
 	g_signal_handlers_disconnect_matched (
 		client, G_SIGNAL_MATCH_FUNC, 0, 0, NULL,
@@ -227,7 +236,7 @@ memo_shell_sidebar_client_opened_cb (EMemoShellSidebar *memo_shell_sidebar,
 
 static void
 memo_shell_sidebar_default_opened_cb (EMemoShellSidebar *memo_shell_sidebar,
-                                      ECalendarStatus status,
+                                      const GError *error,
                                       ECal *client)
 {
 	EShellView *shell_view;
@@ -236,12 +245,14 @@ memo_shell_sidebar_default_opened_cb (EMemoShellSidebar *memo_shell_sidebar,
 	shell_sidebar = E_SHELL_SIDEBAR (memo_shell_sidebar);
 	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
 
-	if (status == E_CALENDAR_STATUS_AUTHENTICATION_FAILED ||
-		status == E_CALENDAR_STATUS_AUTHENTICATION_REQUIRED)
+	if (g_error_matches (error, E_CALENDAR_ERROR,
+		E_CALENDAR_STATUS_AUTHENTICATION_FAILED) ||
+	    g_error_matches (error, E_CALENDAR_ERROR,
+		E_CALENDAR_STATUS_AUTHENTICATION_REQUIRED))
 		e_auth_cal_forget_password (client);
 
 	/* Handle errors. */
-	switch (status) {
+	switch (error ? error->code : E_CALENDAR_STATUS_OK) {
 		case E_CALENDAR_STATUS_OK:
 			break;
 
@@ -253,13 +264,18 @@ memo_shell_sidebar_default_opened_cb (EMemoShellSidebar *memo_shell_sidebar,
 			return;
 
 		default:
+			e_alert_run_dialog_for_args (
+				GTK_WINDOW (e_shell_view_get_shell_window (shell_view)),
+				"calendar:failed-open-memos",
+				error->message, NULL);
+
 			e_memo_shell_sidebar_remove_source (
 				memo_shell_sidebar,
 				e_cal_get_source (client));
 			return;
 	}
 
-	g_assert (status == E_CALENDAR_STATUS_OK);
+	g_assert (error == NULL);
 
 	g_signal_handlers_disconnect_matched (
 		client, G_SIGNAL_MATCH_FUNC, 0, 0, NULL,
@@ -301,7 +317,7 @@ memo_shell_sidebar_set_default (EMemoShellSidebar *memo_shell_sidebar,
 	g_return_if_fail (client != NULL);
 
 	g_signal_connect_swapped (
-		client, "cal-opened",
+		client, "cal-opened-ex",
 		G_CALLBACK (memo_shell_sidebar_default_opened_cb),
 		memo_shell_sidebar);
 
@@ -894,7 +910,7 @@ e_memo_shell_sidebar_add_source (EMemoShellSidebar *memo_shell_sidebar,
 	g_free (message);
 
 	g_signal_connect_swapped (
-		client, "cal-opened",
+		client, "cal-opened-ex",
 		G_CALLBACK (memo_shell_sidebar_client_opened_cb),
 		memo_shell_sidebar);
 
