@@ -417,6 +417,21 @@ em_composer_prefs_construct (EMComposerPrefs *prefs,
 		shell_settings, "composer-prompt-only-bcc",
 		widget, "active");
 
+	widget = e_builder_get_widget (prefs->builder, "chkPromptPrivateListReply");
+	e_mutual_binding_new (
+		shell_settings, "composer-prompt-private-list-reply",
+		widget, "active");
+
+	widget = e_builder_get_widget (prefs->builder, "chkPromptReplyManyRecips");
+	e_mutual_binding_new (
+		shell_settings, "composer-prompt-reply-many-recips",
+		widget, "active");
+
+	widget = e_builder_get_widget (prefs->builder, "chkPromptListReplyTo");
+	e_mutual_binding_new (
+		shell_settings, "composer-prompt-list-reply-to",
+		widget, "active");
+
 	widget = e_builder_get_widget (prefs->builder, "chkAutoSmileys");
 	e_mutual_binding_new (
 		shell_settings, "composer-magic-smileys",
@@ -437,6 +452,16 @@ em_composer_prefs_construct (EMComposerPrefs *prefs,
 		shell_settings, "composer-outlook-filenames",
 		widget, "active");
 
+	widget = e_builder_get_widget (prefs->builder, "chkIgnoreListReplyTo");
+	e_mutual_binding_new (
+		shell_settings, "composer-ignore-list-reply-to",
+		widget, "active");
+
+	widget = e_builder_get_widget (prefs->builder, "chkGroupReplyToList");
+	e_mutual_binding_new (
+		shell_settings, "composer-group-reply-to-list",
+		widget, "active");
+
 	widget = e_builder_get_widget (prefs->builder, "chkTopSignature");
 	e_mutual_binding_new (
 		shell_settings, "composer-top-signature",
