@@ -29,7 +29,7 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <mail/em-event.h>
-#include <e-util/e-alert.h>
+#include <e-util/e-alert-dialog.h>
 #include <e-util/e-util.h>
 #include <e-util/e-icon-factory.h>
 
@@ -397,12 +397,19 @@ action_toggle_face_cb (GtkToggleAction *action, EMsgComposer *composer)
 
 /* ----------------------------------------------------------------- */
 
+gint e_plugin_lib_enable (EPlugin *ep, gint enable);
 gboolean e_plugin_ui_init (GtkUIManager *ui_manager, EMsgComposer *composer);
 GtkWidget *e_plugin_lib_get_configure_widget (EPlugin *epl);
 void face_handle_send (EPlugin *ep, EMEventTargetComposer *target);
 
 /* ----------------------------------------------------------------- */
 
+gint
+e_plugin_lib_enable (EPlugin *ep, gint enable)
+{
+	return 0;
+}
+
 gboolean
 e_plugin_ui_init (GtkUIManager *ui_manager,
 		  EMsgComposer *composer)
