@@ -203,7 +203,7 @@ set_description (ECalComponent *comp, CamelMimeMessage *message)
 
 	byte_array = g_byte_array_new ();
 	stream = camel_stream_mem_new_with_byte_array (byte_array);
-	camel_data_wrapper_decode_to_stream (content, stream);
+	camel_data_wrapper_decode_to_stream (content, stream, NULL);
 	str = g_strndup ((gchar *) byte_array->data, byte_array->len);
 	g_object_unref (stream);
 
@@ -509,12 +509,21 @@ get_question_create_new (ECalSourceType source_type)
 
 	switch (source_type) {
 	case E_CAL_SOURCE_TYPE_EVENT:
+		/* Translators: Codewise it is impossible to provide separate strings for all
+		   combinations of singular and plural. Please translate it in the way that you
+		   feel is most appropriate for your language. */
 		ask = _("Selected calendar contains some events for the given mails already. Would you like to create new events anyway?");
 		break;
 	case E_CAL_SOURCE_TYPE_TODO:
+		/* Translators: Codewise it is impossible to provide separate strings for all
+		   combinations of singular and plural. Please translate it in the way that you
+		   feel is most appropriate for your language. */
 		ask = _("Selected task list contains some tasks for the given mails already. Would you like to create new tasks anyway?");
 		break;
 	case E_CAL_SOURCE_TYPE_JOURNAL:
+		/* Translators: Codewise it is impossible to provide separate strings for all
+		   combinations of singular and plural. Please translate it in the way that you
+		   feel is most appropriate for your language. */
 		ask = _("Selected memo list contains some memos for the given mails already. Would you like to create new memos anyway?");
 		break;
 	default:
@@ -533,18 +542,27 @@ get_question_create_new_n (ECalSourceType source_type, gint count)
 	switch (source_type) {
 	case E_CAL_SOURCE_TYPE_EVENT:
 		ask = ngettext (
+			/* Translators: Codewise it is impossible to provide separate strings for all
+			   combinations of singular and plural. Please translate it in the way that you
+			   feel is most appropriate for your language. */
 			"Selected calendar contains an event for the given mail already. Would you like to create new event anyway?",
 			"Selected calendar contains events for the given mails already. Would you like to create new events anyway?",
 			count);
 		break;
 	case E_CAL_SOURCE_TYPE_TODO:
 		ask = ngettext (
+			/* Translators: Codewise it is impossible to provide separate strings for all
+			   combinations of singular and plural. Please translate it in the way that you
+			   feel is most appropriate for your language. */
 			"Selected task list contains a task for the given mail already. Would you like to create new task anyway?",
 			"Selected task list contains tasks for the given mails already. Would you like to create new tasks anyway?",
 			count);
 		break;
 	case E_CAL_SOURCE_TYPE_JOURNAL:
 		ask = ngettext (
+			/* Translators: Codewise it is impossible to provide separate strings for all
+			   combinations of singular and plural. Please translate it in the way that you
+			   feel is most appropriate for your language. */
 			"Selected memo list contains a memo for the given mail already. Would you like to create new memo anyway?",
 			"Selected memo list contains memos for the given mails already. Would you like to create new memos anyway?",
 			count);
@@ -893,18 +911,18 @@ text_contains_nonwhitespace (const gchar *text, gint len)
 static gchar *
 get_selected_text (EMailReader *reader)
 {
-	EMFormatHTMLDisplay *html_display;
-	GtkHTML *html;
+	EMFormatHTML *formatter;
+	EWebView *web_view;
 	gchar *text = NULL;
 	gint len;
 
-	html_display = e_mail_reader_get_html_display (reader);
-	html = EM_FORMAT_HTML (html_display)->html;
+	formatter = e_mail_reader_get_formatter (reader);
+	web_view = em_format_html_get_web_view (formatter);
 
-	if (!gtk_html_command (html, "is-selection-active"))
+	if (!e_web_view_is_selection_active (web_view))
 		return NULL;
 
-	text = gtk_html_get_selection_plain_text (html, &len);
+	text = gtk_html_get_selection_plain_text (GTK_HTML (web_view), &len);
 
 	if (text == NULL || !text_contains_nonwhitespace (text, len)) {
 		g_free (text);
@@ -1082,12 +1100,10 @@ static GtkActionEntry single_selection_entries[] = {
 
 static void
 update_actions_any_cb (EMailReader *reader,
+                       guint32 state,
                        GtkActionGroup *action_group)
 {
 	gboolean sensitive;
-	guint32 state;
-
-	state = e_mail_reader_check_state (reader);
 
 	sensitive =
 		(state & E_MAIL_READER_SELECTION_SINGLE) ||
@@ -1098,12 +1114,10 @@ update_actions_any_cb (EMailReader *reader,
 
 static void
 update_actions_one_cb (EMailReader *reader,
+                       guint32 state,
                        GtkActionGroup *action_group)
 {
 	gboolean sensitive;
-	guint32 state;
-
-	state = e_mail_reader_check_state (reader);
 
 	sensitive = (state & E_MAIL_READER_SELECTION_SINGLE);
 
