@@ -99,7 +99,7 @@ org_gnome_vcard_inline_decode (VCardInlinePObject *vcard_object,
 	/* Stream takes ownership of the byte array. */
 	stream = camel_stream_mem_new_with_byte_array (array);
 	data_wrapper = camel_medium_get_content (medium);
-	camel_data_wrapper_decode_to_stream (data_wrapper, stream);
+	camel_data_wrapper_decode_to_stream (data_wrapper, stream, NULL);
 
 	/* because the result is not NULL-terminated */
 	g_byte_array_append (array, padding, 2);
@@ -114,13 +114,13 @@ org_gnome_vcard_inline_decode (VCardInlinePObject *vcard_object,
 
 static void
 org_gnome_vcard_inline_book_open_cb (EBook *book,
-                                     EBookStatus status,
+                                     const GError *error,
                                      gpointer user_data)
 {
 	GList *contact_list = user_data;
 	GList *iter;
 
-	if (status != E_BOOK_ERROR_OK)
+	if (error)
 		goto exit;
 
 	for (iter = contact_list; iter != NULL; iter = iter->next)
