@@ -56,6 +56,7 @@
 
 struct _EAttachmentPrivate {
 	GFile *file;
+	GIcon *icon;
 	GFileInfo *file_info;
 	GCancellable *cancellable;
 	CamelMimePart *mime_part;
@@ -85,6 +86,7 @@ enum {
 	PROP_ENCRYPTED,
 	PROP_FILE,
 	PROP_FILE_INFO,
+	PROP_ICON,
 	PROP_LOADING,
 	PROP_MIME_PART,
 	PROP_PERCENT,
@@ -357,7 +359,11 @@ attachment_update_icon_column (EAttachment *attachment)
 		E_ATTACHMENT_STORE_COLUMN_ICON, icon,
 		-1);
 
-	g_object_unref (icon);
+	/* Cache the icon to reuse for things like drag-n-drop. */
+	if (attachment->priv->icon != NULL)
+		g_object_unref (attachment->priv->icon);
+	attachment->priv->icon = icon;
+	g_object_notify (G_OBJECT (attachment), "icon");
 }
 
 static void
@@ -601,6 +607,12 @@ attachment_get_property (GObject *object,
 				E_ATTACHMENT (object)));
 			return;
 
+		case PROP_ICON:
+			g_value_set_object (
+				value, e_attachment_get_icon (
+				E_ATTACHMENT (object)));
+			return;
+
 		case PROP_SHOWN:
 			g_value_set_boolean (
 				value, e_attachment_get_shown (
@@ -659,6 +671,11 @@ attachment_dispose (GObject *object)
 		priv->file = NULL;
 	}
 
+	if (priv->icon != NULL) {
+		g_object_unref (priv->icon);
+		priv->icon = NULL;
+	}
+
 	if (priv->file_info != NULL) {
 		g_object_unref (priv->file_info);
 		priv->file_info = NULL;
@@ -771,6 +788,16 @@ attachment_class_init (EAttachmentClass *class)
 			G_TYPE_FILE_INFO,
 			G_PARAM_READABLE));
 
+	g_object_class_install_property (
+		object_class,
+		PROP_ICON,
+		g_param_spec_object (
+			"icon",
+			"Icon",
+			NULL,
+			G_TYPE_ICON,
+			G_PARAM_READABLE));
+
 	g_object_class_install_property (
 		object_class,
 		PROP_LOADING,
@@ -784,11 +811,11 @@ attachment_class_init (EAttachmentClass *class)
 	g_object_class_install_property (
 		object_class,
 		PROP_MIME_PART,
-		g_param_spec_boxed (
+		g_param_spec_object (
 			"mime-part",
 			"MIME Part",
 			NULL,
-			E_TYPE_CAMEL_OBJECT,
+			CAMEL_TYPE_MIME_PART,
 			G_PARAM_READWRITE));
 
 	g_object_class_install_property (
@@ -1053,7 +1080,7 @@ e_attachment_add_to_multipart (EAttachment *attachment,
 			CAMEL_STREAM_FILTER (filtered_stream),
 			CAMEL_MIME_FILTER (filter));
 		camel_data_wrapper_decode_to_stream (
-			wrapper, filtered_stream);
+			wrapper, filtered_stream, NULL);
 		g_object_unref (filtered_stream);
 		g_object_unref (stream);
 
@@ -1178,6 +1205,14 @@ e_attachment_get_file_info (EAttachment *attachment)
 	return attachment->priv->file_info;
 }
 
+GIcon *
+e_attachment_get_icon (EAttachment *attachment)
+{
+	g_return_val_if_fail (E_IS_ATTACHMENT (attachment), NULL);
+
+	return attachment->priv->icon;
+}
+
 gboolean
 e_attachment_get_loading (EAttachment *attachment)
 {
@@ -1528,9 +1563,9 @@ attachment_load_finish (LoadContext *load_context)
 	size = g_memory_output_stream_get_data_size (output_stream);
 
 	stream = camel_stream_mem_new_with_buffer (data, size);
-	camel_data_wrapper_construct_from_stream (wrapper, stream);
+	camel_data_wrapper_construct_from_stream (wrapper, stream, NULL);
 	camel_data_wrapper_set_mime_type (wrapper, mime_type);
-	camel_stream_close (stream);
+	camel_stream_close (stream, NULL);
 	g_object_unref (stream);
 
 	mime_part = camel_mime_part_new ();
@@ -2463,7 +2498,7 @@ attachment_save_got_output_stream (SaveContext *save_context)
 	stream = camel_stream_mem_new ();
 	camel_stream_mem_set_byte_array (CAMEL_STREAM_MEM (stream), buffer);
 	wrapper = camel_medium_get_content (CAMEL_MEDIUM (mime_part));
-	camel_data_wrapper_decode_to_stream (wrapper, stream);
+	camel_data_wrapper_decode_to_stream (wrapper, stream, NULL);
 	g_object_unref (stream);
 
 	/* Load the buffer into a GMemoryInputStream.
