@@ -1,24 +1,24 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * e-selection-model-array.c
- * Copyright 2000, 2001, Ximian, Inc.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
  *
  * Authors:
- *   Chris Lahey <clahey@ximian.com>
+ *		Chris Lahey <clahey@ximian.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License, version 2, as published by the Free Software Foundation.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
  */
 
 #include <config.h>
@@ -42,7 +42,7 @@ void
 e_selection_model_array_confirm_row_count(ESelectionModelArray *esma)
 {
 	if (esma->eba == NULL) {
-		int row_count = e_selection_model_array_get_row_count(esma);
+		gint row_count = e_selection_model_array_get_row_count(esma);
 		esma->eba = e_bit_array_new(row_count);
 		esma->selected_row = -1;
 		esma->selected_range_end = -1;
@@ -69,7 +69,7 @@ es_row_sorted_to_model (ESelectionModelArray *esma, gint sorted_row)
 
 /* FIXME: Should this deal with moving the selection if it's in single mode? */
 void
-e_selection_model_array_delete_rows(ESelectionModelArray *esma, int row, int count)
+e_selection_model_array_delete_rows(ESelectionModelArray *esma, gint row, gint count)
 {
 	if (esma->eba) {
 		if (E_SELECTION_MODEL(esma)->mode == GTK_SELECTION_SINGLE)
@@ -77,18 +77,38 @@ e_selection_model_array_delete_rows(ESelectionModelArray *esma, int row, int cou
 		else
 			e_bit_array_delete(esma->eba, row, count);
 
-		if (esma->cursor_row_sorted >= e_bit_array_bit_count (esma->eba)) {
-			esma->cursor_row_sorted = e_bit_array_bit_count (esma->eba) - 1;
-			esma->selection_start_row--;
-		}
+		if (esma->cursor_row >= row && esma->cursor_row < row + count) {
+			/* we should move the cursor_row, because some lines before us are going to be removed */
+			if (esma->cursor_row_sorted >= e_bit_array_bit_count (esma->eba)) {
+				esma->cursor_row_sorted = e_bit_array_bit_count (esma->eba) - 1;
+			}
 
-		if (esma->cursor_row_sorted >= 0) {
-			esma->cursor_row = es_row_sorted_to_model (esma, esma->cursor_row_sorted);
-			e_bit_array_change_one_row (esma->eba, esma->cursor_row, TRUE);
+			if (esma->cursor_row_sorted >= 0) {
+				esma->cursor_row = es_row_sorted_to_model (esma, esma->cursor_row_sorted);
+				esma->selection_start_row = 0;
+				e_bit_array_change_one_row (esma->eba, esma->cursor_row, TRUE);
+			} else {
+				esma->cursor_row = -1;
+				esma->cursor_row_sorted = -1;
+				esma->selection_start_row = 0;
+			}
 		} else {
-			esma->cursor_row = -1;
-			esma->cursor_row_sorted = -1;
-			esma->selection_start_row = 0;
+			/* some code earlier changed the selected row, so just update the sorted one */
+			if (esma->cursor_row >= row)
+				esma->cursor_row = MAX (0, esma->cursor_row - count);
+
+			if (esma->cursor_row >= e_bit_array_bit_count (esma->eba))
+				esma->cursor_row = e_bit_array_bit_count (esma->eba) - 1;
+
+			if (esma->cursor_row >= 0) {
+				esma->cursor_row_sorted = es_row_model_to_sorted (esma, esma->cursor_row);
+				esma->selection_start_row = 0;
+				e_bit_array_change_one_row (esma->eba, esma->cursor_row, TRUE);
+			} else {
+				esma->cursor_row = -1;
+				esma->cursor_row_sorted = -1;
+				esma->selection_start_row = 0;
+			}
 		}
 
 		esma->selected_row = -1;
@@ -99,7 +119,7 @@ e_selection_model_array_delete_rows(ESelectionModelArray *esma, int row, int cou
 }
 
 void
-e_selection_model_array_insert_rows(ESelectionModelArray *esma, int row, int count)
+e_selection_model_array_insert_rows(ESelectionModelArray *esma, gint row, gint count)
 {
 	if (esma->eba) {
 		e_bit_array_insert(esma->eba, row, count);
@@ -115,7 +135,7 @@ e_selection_model_array_insert_rows(ESelectionModelArray *esma, int row, int cou
 }
 
 void
-e_selection_model_array_move_row(ESelectionModelArray *esma, int old_row, int new_row)
+e_selection_model_array_move_row(ESelectionModelArray *esma, gint old_row, gint new_row)
 {
 	ESelectionModel *esm = E_SELECTION_MODEL(esma);
 
@@ -128,9 +148,9 @@ e_selection_model_array_move_row(ESelectionModelArray *esma, int old_row, int ne
 		new_row_sorted = es_row_model_to_sorted (esma, new_row);
 
 		if (old_row_sorted < esma->cursor_row_sorted && esma->cursor_row_sorted < new_row_sorted)
-			esma->cursor_row_sorted --;
+			esma->cursor_row_sorted--;
 		else if (new_row_sorted < esma->cursor_row_sorted && esma->cursor_row_sorted < old_row_sorted)
-			esma->cursor_row_sorted ++;
+			esma->cursor_row_sorted++;
 
 		e_bit_array_move_row(esma->eba, old_row, new_row);
 
@@ -174,7 +194,7 @@ esma_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *ps
 {
 	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY (object);
 
-	switch (prop_id){
+	switch (prop_id) {
 	case PROP_CURSOR_ROW:
 		g_value_set_int (value, esma->cursor_row);
 		break;
@@ -191,7 +211,7 @@ esma_set_property (GObject *object, guint prop_id, const GValue *value, GParamSp
 	ESelectionModel *esm = E_SELECTION_MODEL (object);
 	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY (object);
 
-	switch (prop_id){
+	switch (prop_id) {
 	case PROP_CURSOR_ROW:
 		e_selection_model_do_something(esm, g_value_get_int (value), esma->cursor_col, 0);
 		break;
@@ -337,7 +357,7 @@ esma_invert_selection (ESelectionModel *selection)
 	e_selection_model_cursor_changed(E_SELECTION_MODEL(esma), -1, -1);
 }
 
-static int
+static gint
 esma_row_count (ESelectionModel *selection)
 {
 	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
@@ -346,7 +366,7 @@ esma_row_count (ESelectionModel *selection)
 }
 
 static void
-esma_change_one_row(ESelectionModel *selection, int row, gboolean grow)
+esma_change_one_row(ESelectionModel *selection, gint row, gboolean grow)
 {
 	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
 	e_selection_model_array_confirm_row_count(esma);
@@ -354,7 +374,7 @@ esma_change_one_row(ESelectionModel *selection, int row, gboolean grow)
 }
 
 static void
-esma_change_cursor (ESelectionModel *selection, int row, int col)
+esma_change_cursor (ESelectionModel *selection, gint row, gint col)
 {
 	ESelectionModelArray *esma;
 
@@ -369,9 +389,9 @@ esma_change_cursor (ESelectionModel *selection, int row, int col)
 }
 
 static void
-esma_change_range(ESelectionModel *selection, int start, int end, gboolean grow)
+esma_change_range(ESelectionModel *selection, gint start, gint end, gboolean grow)
 {
-	int i;
+	gint i;
 	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
 	if (start != end) {
 		if (selection->sorter && e_sorter_needs_sorting(selection->sorter)) {
@@ -385,14 +405,14 @@ esma_change_range(ESelectionModel *selection, int start, int end, gboolean grow)
 	}
 }
 
-static int
+static gint
 esma_cursor_row (ESelectionModel *selection)
 {
 	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
 	return esma->cursor_row;
 }
 
-static int
+static gint
 esma_cursor_col (ESelectionModel *selection)
 {
 	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
@@ -400,7 +420,7 @@ esma_cursor_col (ESelectionModel *selection)
 }
 
 static void
-esma_real_select_single_row (ESelectionModel *selection, int row)
+esma_real_select_single_row (ESelectionModel *selection, gint row)
 {
 	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
 
@@ -414,10 +434,10 @@ esma_real_select_single_row (ESelectionModel *selection, int row)
 }
 
 static void
-esma_select_single_row (ESelectionModel *selection, int row)
+esma_select_single_row (ESelectionModel *selection, gint row)
 {
 	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
-	int selected_row = esma->selected_row;
+	gint selected_row = esma->selected_row;
 	esma_real_select_single_row (selection, row);
 
 	if (selected_row != -1 && esma->eba && selected_row < e_bit_array_bit_count (esma->eba)) {
@@ -431,7 +451,7 @@ esma_select_single_row (ESelectionModel *selection, int row)
 }
 
 static void
-esma_toggle_single_row (ESelectionModel *selection, int row)
+esma_toggle_single_row (ESelectionModel *selection, gint row)
 {
 	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
 
@@ -445,13 +465,13 @@ esma_toggle_single_row (ESelectionModel *selection, int row)
 }
 
 static void
-esma_real_move_selection_end (ESelectionModel *selection, int row)
+esma_real_move_selection_end (ESelectionModel *selection, gint row)
 {
 	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
-	int old_start;
-	int old_end;
-	int new_start;
-	int new_end;
+	gint old_start;
+	gint old_end;
+	gint new_start;
+	gint new_end;
 	if (selection->sorter && e_sorter_needs_sorting(selection->sorter)) {
 		old_start = MIN (e_sorter_model_to_sorted(selection->sorter, esma->selection_start_row),
 				 e_sorter_model_to_sorted(selection->sorter, esma->cursor_row));
@@ -481,18 +501,18 @@ esma_real_move_selection_end (ESelectionModel *selection, int row)
 }
 
 static void
-esma_move_selection_end (ESelectionModel *selection, int row)
+esma_move_selection_end (ESelectionModel *selection, gint row)
 {
 	esma_real_move_selection_end (selection, row);
 	e_selection_model_selection_changed(selection);
 }
 
 static void
-esma_set_selection_end (ESelectionModel *selection, int row)
+esma_set_selection_end (ESelectionModel *selection, gint row)
 {
 	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
-	int selected_range_end = esma->selected_range_end;
-	int view_row = e_sorter_model_to_sorted(selection->sorter, row);
+	gint selected_range_end = esma->selected_range_end;
+	gint view_row = e_sorter_model_to_sorted(selection->sorter, row);
 
 	esma_real_select_single_row(selection, esma->selection_start_row);
 	esma->cursor_row = esma->selection_start_row;
@@ -510,7 +530,7 @@ esma_set_selection_end (ESelectionModel *selection, int row)
 	e_selection_model_selection_changed(selection);
 }
 
-int
+gint
 e_selection_model_array_get_row_count (ESelectionModelArray *esma)
 {
 	g_return_val_if_fail(esma != NULL, 0);
@@ -522,7 +542,6 @@ e_selection_model_array_get_row_count (ESelectionModelArray *esma)
 		return 0;
 }
 
-
 static void
 e_selection_model_array_init (ESelectionModelArray *esma)
 {
@@ -549,37 +568,37 @@ e_selection_model_array_class_init (ESelectionModelArrayClass *klass)
 	object_class->get_property = esma_get_property;
 	object_class->set_property = esma_set_property;
 
-	esm_class->is_row_selected    = esma_is_row_selected    ;
-	esm_class->foreach            = esma_foreach            ;
-	esm_class->clear              = esma_clear              ;
-	esm_class->selected_count     = esma_selected_count     ;
-	esm_class->select_all         = esma_select_all         ;
-	esm_class->invert_selection   = esma_invert_selection   ;
-	esm_class->row_count          = esma_row_count          ;
+	esm_class->is_row_selected    = esma_is_row_selected;
+	esm_class->foreach            = esma_foreach;
+	esm_class->clear              = esma_clear;
+	esm_class->selected_count     = esma_selected_count;
+	esm_class->select_all         = esma_select_all;
+	esm_class->invert_selection   = esma_invert_selection;
+	esm_class->row_count          = esma_row_count;
 
-	esm_class->change_one_row     = esma_change_one_row     ;
-	esm_class->change_cursor      = esma_change_cursor      ;
-	esm_class->cursor_row         = esma_cursor_row         ;
-	esm_class->cursor_col         = esma_cursor_col         ;
+	esm_class->change_one_row     = esma_change_one_row;
+	esm_class->change_cursor      = esma_change_cursor;
+	esm_class->cursor_row         = esma_cursor_row;
+	esm_class->cursor_col         = esma_cursor_col;
 
-	esm_class->select_single_row  = esma_select_single_row  ;
-	esm_class->toggle_single_row  = esma_toggle_single_row  ;
-	esm_class->move_selection_end = esma_move_selection_end ;
-	esm_class->set_selection_end  = esma_set_selection_end  ;
+	esm_class->select_single_row  = esma_select_single_row;
+	esm_class->toggle_single_row  = esma_toggle_single_row;
+	esm_class->move_selection_end = esma_move_selection_end;
+	esm_class->set_selection_end  = esma_set_selection_end;
 
-	klass->get_row_count          = NULL                    ;
+	klass->get_row_count          = NULL;
 
 	g_object_class_install_property (object_class, PROP_CURSOR_ROW,
 					 g_param_spec_int ("cursor_row",
-							   _("Cursor Row"),
-							   /*_( */"XXX blurb" /*)*/,
+							   "Cursor Row",
+							   NULL,
 							   0, G_MAXINT, 0,
 							   G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_CURSOR_COL,
 					 g_param_spec_int ("cursor_col",
-							   _("Cursor Column"),
-							   /*_( */"XXX blurb" /*)*/,
+							   "Cursor Column",
+							   NULL,
 							   0, G_MAXINT, 0,
 							   G_PARAM_READWRITE));
 }
