@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -186,26 +186,30 @@ etgl_double_click (GtkObject *object, gint model_row, gint model_col, GdkEvent *
 	e_table_group_double_click (E_TABLE_GROUP(etgl), model_row, model_col, event);
 }
 
-static gint
-etgl_key_press (GtkObject *object, gint row, gint col, GdkEvent *event, ETableGroupLeaf *etgl)
+static gboolean
+etgl_key_press (GtkObject *object,
+                gint row,
+                gint col,
+                GdkEvent *event,
+                ETableGroupLeaf *etgl)
 {
 	if (row < E_TABLE_SUBSET(etgl->ets)->n_map && row >= 0)
-		return e_table_group_key_press (E_TABLE_GROUP(etgl),
-						E_TABLE_SUBSET(etgl->ets)->map_table[row],
-						col,
-						event);
+		return e_table_group_key_press (
+			E_TABLE_GROUP(etgl),
+			E_TABLE_SUBSET(etgl->ets)->map_table[row],
+			col, event);
 	else
-		return 0;
+		return FALSE;
 }
 
-static gint
+static gboolean
 etgl_start_drag (GtkObject *object, gint model_row, gint model_col, GdkEvent *event,
 		 ETableGroupLeaf *etgl)
 {
 	return e_table_group_start_drag (E_TABLE_GROUP(etgl), model_row, model_col, event);
 }
 
-static gint
+static gboolean
 etgl_right_click (GtkObject *object, gint view_row, gint model_col, GdkEvent *event,
 		  ETableGroupLeaf *etgl)
 {
@@ -215,11 +219,15 @@ etgl_right_click (GtkObject *object, gint view_row, gint model_col, GdkEvent *ev
 						  model_col,
 						  event);
 	else
-		return 0;
+		return FALSE;
 }
 
-static gint
-etgl_click (GtkObject *object, gint row, gint col, GdkEvent *event, ETableGroupLeaf *etgl)
+static gboolean
+etgl_click (GtkObject *object,
+            gint row,
+            gint col,
+            GdkEvent *event,
+            ETableGroupLeaf *etgl)
 {
 	if (row < E_TABLE_SUBSET(etgl->ets)->n_map)
 		return e_table_group_click (E_TABLE_GROUP(etgl),
@@ -227,7 +235,7 @@ etgl_click (GtkObject *object, gint row, gint col, GdkEvent *event, ETableGroupL
 					    col,
 					    event);
 	else
-		return 0;
+		return FALSE;
 }
 
 static void
@@ -349,7 +357,9 @@ etgl_increment (ETableGroup *etg, gint position, gint amount)
 	ETableGroupLeaf *etgl = E_TABLE_GROUP_LEAF (etg);
 
 	if (E_IS_TABLE_SUBSET_VARIABLE(etgl->ets)) {
-		e_table_subset_variable_increment (E_TABLE_SUBSET_VARIABLE(etgl->ets), position, amount);
+		e_table_subset_variable_increment (
+			E_TABLE_SUBSET_VARIABLE (etgl->ets),
+			position, amount);
 	}
 }
 
@@ -359,11 +369,13 @@ etgl_decrement (ETableGroup *etg, gint position, gint amount)
 	ETableGroupLeaf *etgl = E_TABLE_GROUP_LEAF (etg);
 
 	if (E_IS_TABLE_SUBSET_VARIABLE(etgl->ets)) {
-		e_table_subset_variable_decrement (E_TABLE_SUBSET_VARIABLE(etgl->ets), position, amount);
+		e_table_subset_variable_decrement (
+			E_TABLE_SUBSET_VARIABLE (etgl->ets),
+			position, amount);
 	}
 }
 
-static int
+static gint
 etgl_row_count (ETableGroup *etg)
 {
 	ETableGroupLeaf *etgl = E_TABLE_GROUP_LEAF (etg);
@@ -377,7 +389,9 @@ etgl_set_focus (ETableGroup *etg, EFocus direction, gint view_col)
 	ETableGroupLeaf *etgl = E_TABLE_GROUP_LEAF (etg);
 
 	if (direction == E_FOCUS_END) {
-		e_table_item_set_cursor (etgl->item, view_col, e_table_model_row_count(E_TABLE_MODEL(etgl->ets)) - 1);
+		e_table_item_set_cursor (
+			etgl->item, view_col,
+			e_table_model_row_count (E_TABLE_MODEL(etgl->ets)) - 1);
 	} else {
 		e_table_item_set_cursor (etgl->item, view_col, 0);
 	}
@@ -400,7 +414,7 @@ etgl_get_printable (ETableGroup *etg)
 }
 
 static void
-etgl_compute_location (ETableGroup *etg, int *x, int *y, int *row, int *col)
+etgl_compute_location (ETableGroup *etg, gint *x, gint *y, gint *row, gint *col)
 {
 	ETableGroupLeaf *etgl = E_TABLE_GROUP_LEAF (etg);
 
@@ -408,15 +422,26 @@ etgl_compute_location (ETableGroup *etg, int *x, int *y, int *row, int *col)
 }
 
 static void
-etgl_compute_mouse_over (ETableGroup *etg, int x, int y, int *row, int *col)
+etgl_get_mouse_over (ETableGroup *etg, gint *row, gint *col)
 {
 	ETableGroupLeaf *etgl = E_TABLE_GROUP_LEAF (etg);
 
-	e_table_item_compute_mouse_over (etgl->item, x, y, row, col);
+	if (etgl->item && etgl->item->motion_row > -1 && etgl->item->motion_col > -1) {
+		if (row)
+			*row = etgl->item->motion_row;
+		if (col)
+			*col = etgl->item->motion_col;
+	}
 }
 
 static void
-etgl_get_cell_geometry (ETableGroup *etg, int *row, int *col, int *x, int *y, int *width, int *height)
+etgl_get_cell_geometry (ETableGroup *etg,
+                        gint *row,
+                        gint *col,
+                        gint *x,
+                        gint *y,
+                        gint *width,
+                        gint *height)
 {
 	ETableGroupLeaf *etgl = E_TABLE_GROUP_LEAF (etg);
 
@@ -424,7 +449,10 @@ etgl_get_cell_geometry (ETableGroup *etg, int *row, int *col, int *x, int *y, in
 }
 
 static void
-etgl_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
+etgl_set_property (GObject *object,
+                   guint prop_id,
+                   const GValue *value,
+                   GParamSpec *pspec)
 {
 	ETableGroup *etg = E_TABLE_GROUP (object);
 	ETableGroupLeaf *etgl = E_TABLE_GROUP_LEAF (object);
@@ -573,90 +601,90 @@ etgl_class_init (ETableGroupLeafClass *klass)
 	e_group_class->get_focus_column = etgl_get_focus_column;
 	e_group_class->get_printable = etgl_get_printable;
 	e_group_class->compute_location = etgl_compute_location;
-	e_group_class->compute_mouse_over = etgl_compute_mouse_over;
+	e_group_class->get_mouse_over = etgl_get_mouse_over;
 	e_group_class->get_cell_geometry = etgl_get_cell_geometry;
 
 	g_object_class_install_property (object_class, PROP_TABLE_ALTERNATING_ROW_COLORS,
 					 g_param_spec_boolean ("alternating_row_colors",
-							       _( "Alternating Row Colors" ),
-							       _( "Alternating Row Colors" ),
+							       "Alternating Row Colors",
+							       "Alternating Row Colors",
 							       FALSE,
 							       G_PARAM_WRITABLE));
 
 	g_object_class_install_property (object_class, PROP_TABLE_HORIZONTAL_DRAW_GRID,
 					 g_param_spec_boolean ("horizontal_draw_grid",
-							       _( "Horizontal Draw Grid" ),
-							       _( "Horizontal Draw Grid" ),
+							       "Horizontal Draw Grid",
+							       "Horizontal Draw Grid",
 							       FALSE,
 							       G_PARAM_WRITABLE));
 
 	g_object_class_install_property (object_class, PROP_TABLE_VERTICAL_DRAW_GRID,
 					 g_param_spec_boolean ("vertical_draw_grid",
-							       _( "Vertical Draw Grid" ),
-							       _( "Vertical Draw Grid" ),
+							       "Vertical Draw Grid",
+							       "Vertical Draw Grid",
 							       FALSE,
 							       G_PARAM_WRITABLE));
 
 	g_object_class_install_property (object_class, PROP_TABLE_DRAW_FOCUS,
 					 g_param_spec_boolean ("drawfocus",
-							       _( "Draw focus" ),
-							       _( "Draw focus" ),
+							       "Draw focus",
+							       "Draw focus",
 							       FALSE,
 							       G_PARAM_WRITABLE));
 
 	g_object_class_install_property (object_class, PROP_CURSOR_MODE,
 					 g_param_spec_int ("cursor_mode",
-							   _( "Cursor mode" ),
-							   _( "Cursor mode" ),
+							   "Cursor mode",
+							   "Cursor mode",
 							   E_CURSOR_LINE, E_CURSOR_SPREADSHEET, E_CURSOR_LINE,
 							   G_PARAM_WRITABLE));
 
 	g_object_class_install_property (object_class, PROP_LENGTH_THRESHOLD,
 					 g_param_spec_int ("length_threshold",
-							   _( "Length Threshold" ),
-							   _( "Length Threshold" ),
+							   "Length Threshold",
+							   "Length Threshold",
 							   -1, G_MAXINT, 0,
 							   G_PARAM_WRITABLE));
 
 	g_object_class_install_property (object_class, PROP_SELECTION_MODEL,
 					 g_param_spec_object ("selection_model",
-							      _( "Selection model" ),
-							      _( "Selection model" ),
+							      "Selection model",
+							      "Selection model",
 							      E_SELECTION_MODEL_TYPE,
 							      G_PARAM_WRITABLE));
 
 	g_object_class_install_property (object_class, PROP_HEIGHT,
 					 g_param_spec_double ("height",
-							      _( "Height" ),
-							      _( "Height" ),
+							      "Height",
+							      "Height",
 							      0.0, G_MAXDOUBLE, 0.0,
 							      G_PARAM_READABLE));
 
 	g_object_class_install_property (object_class, PROP_WIDTH,
 					 g_param_spec_double ("width",
-							      _( "Width" ),
-							      _( "Width" ),
+							      "Width",
+							      "Width",
 							      0.0, G_MAXDOUBLE, 0.0,
 							      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_MINIMUM_WIDTH,
 					 g_param_spec_double ("minimum_width",
-							      _( "Minimum width" ),
-							      _( "Minimum Width" ),
+							      "Minimum width",
+							      "Minimum Width",
 							      0.0, G_MAXDOUBLE, 0.0,
 							      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_FROZEN,
 					 g_param_spec_boolean ("frozen",
-							       _( "Frozen" ),
-							       _( "Frozen" ),
+							       "Frozen",
+							       "Frozen",
 							       FALSE,
 							       G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_UNIFORM_ROW_HEIGHT,
 					 g_param_spec_boolean ("uniform_row_height",
-							       _( "Uniform row height" ),
-							       _( "Uniform row height" ),
+							       "Uniform row height",
+							       "Uniform row height",
 							       FALSE,
 							       G_PARAM_READWRITE));
 }
