@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -41,7 +41,7 @@ G_DEFINE_TYPE (ETableMemory, e_table_memory, E_TABLE_MODEL_TYPE)
 
 struct ETableMemoryPriv {
 	gpointer *data;
-	int num_rows;
+	gint num_rows;
 	gint frozen;
 };
 
@@ -64,7 +64,7 @@ etmm_finalize (GObject *object)
 	G_OBJECT_CLASS (e_table_memory_parent_class)->finalize (object);
 }
 
-static int
+static gint
 etmm_row_count (ETableModel *etm)
 {
 	ETableMemory *etmm = E_TABLE_MEMORY (etm);
@@ -120,7 +120,7 @@ e_table_memory_new (void)
  * Return value:
  **/
 gpointer
-e_table_memory_get_data (ETableMemory *etmm, int row)
+e_table_memory_get_data (ETableMemory *etmm, gint row)
 {
 	g_return_val_if_fail(row >= 0, NULL);
 	g_return_val_if_fail(row < etmm->priv->num_rows, NULL);
@@ -137,7 +137,7 @@ e_table_memory_get_data (ETableMemory *etmm, int row)
  *
  **/
 void
-e_table_memory_set_data (ETableMemory *etmm, int row, gpointer data)
+e_table_memory_set_data (ETableMemory *etmm, gint row, gpointer data)
 {
 	g_return_if_fail(row >= 0);
 	g_return_if_fail(row < etmm->priv->num_rows);
@@ -158,7 +158,7 @@ e_table_memory_set_data (ETableMemory *etmm, int row, gpointer data)
  **/
 void
 e_table_memory_insert (ETableMemory *etmm,
-		       int row,
+		       gint row,
 		       gpointer data)
 {
 	g_return_if_fail(row >= -1);
@@ -170,9 +170,12 @@ e_table_memory_insert (ETableMemory *etmm,
 	if (row == -1)
 		row = etmm->priv->num_rows;
 	etmm->priv->data = g_renew(gpointer, etmm->priv->data, etmm->priv->num_rows + 1);
-	memmove(etmm->priv->data + row + 1, etmm->priv->data + row, (etmm->priv->num_rows - row) * sizeof (gpointer));
+	memmove (
+		etmm->priv->data + row + 1,
+		etmm->priv->data + row,
+		(etmm->priv->num_rows - row) * sizeof (gpointer));
 	etmm->priv->data[row] = data;
-	etmm->priv->num_rows ++;
+	etmm->priv->num_rows++;
 	if (!etmm->priv->frozen)
 		e_table_model_row_inserted(E_TABLE_MODEL(etmm), row);
 }
@@ -189,7 +192,7 @@ e_table_memory_insert (ETableMemory *etmm,
  * Return value:
  **/
 gpointer
-e_table_memory_remove (ETableMemory *etmm, int row)
+e_table_memory_remove (ETableMemory *etmm, gint row)
 {
 	gpointer ret;
 
@@ -199,8 +202,11 @@ e_table_memory_remove (ETableMemory *etmm, int row)
 	if (!etmm->priv->frozen)
 		e_table_model_pre_change(E_TABLE_MODEL(etmm));
 	ret = etmm->priv->data[row];
-	memmove(etmm->priv->data + row, etmm->priv->data + row + 1, (etmm->priv->num_rows - row - 1) * sizeof (gpointer));
-	etmm->priv->num_rows --;
+	memmove (
+		etmm->priv->data + row,
+		etmm->priv->data + row + 1,
+		(etmm->priv->num_rows - row - 1) * sizeof (gpointer));
+	etmm->priv->num_rows--;
 	if (!etmm->priv->frozen)
 		e_table_model_row_deleted(E_TABLE_MODEL(etmm), row);
 	return ret;
@@ -244,7 +250,7 @@ e_table_memory_freeze(ETableMemory *etmm)
 	if (priv->frozen == 0)
 		e_table_model_pre_change(E_TABLE_MODEL(etmm));
 
-	priv->frozen ++;
+	priv->frozen++;
 }
 
 /**
@@ -262,7 +268,7 @@ e_table_memory_thaw(ETableMemory *etmm)
 	ETableMemoryPriv *priv = etmm->priv;
 
 	if (priv->frozen > 0)
-		priv->frozen --;
+		priv->frozen--;
 	if (priv->frozen == 0) {
 		e_table_model_changed(E_TABLE_MODEL(etmm));
 	}
